/*
** ###################################################################
**     Processors:          MX8
**
**     Compilers:           GNU C Compiler
**
**     Abstract:
**         CMSIS Peripheral Access Layer for MX8
**
**     Copyright (c) 1997 - 2016 Freescale Semiconductor, Inc.
**     Copyright 2016-2019 NXP
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of the copyright holder nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
**     Revisions:
**
** ###################################################################
*/

/*!
 * @file MX8_dsc_ai.h.h
 * @version 0.0
 * @date 0-00-00
 * @brief CMSIS Peripheral Access Layer for teh DSC AI
 *
 * CMSIS Peripheral Access Layer for the DSC AI
 */

#ifndef HW_DSC_AI_REGISTERS_H
#define HW_DSC_AI_REGISTERS_H                               /**< Symbol preventing repeated inclusion */

// AI - Fractional PLL Local Control Register Memory Map
#define AI_FRAC_PLL_LOCAL_CTRL                0x00U
#define AI_FRAC_PLL_LOCAL_SPECTRUM            0x10U
#define AI_FRAC_PLL_LOCAL_NUMERATOR           0x20U
#define AI_FRAC_PLL_LOCAL_DENOMINATOR         0x30U


// AI Toggle Map

#define AI_PLL0_TOGGLE                (0U)
#define AI_PLL1_TOGGLE                (1U)
#define AI_PLL2_TOGGLE                (2U)
#define AI_OSC24M_TOGGLE              (3U)
#define AI_RC200OSC_TOGGLE            (4U)
#define AI_VDROP_PROCMON_TOGGLE       (5U)
#define AI_TEMP_SENSE_TOGGLE          (6U)
#define AI_LVDS_TRANS_TOGGLE          (7U)
#define AI_NEG_CHARGE_PUMP_TOGGLE     (8U)
#define AI_WELL_LEVEL_SOURCE_TOGGLE   (9U)
#define AI_BANDGAP_REF_TOGGLE         (10U)
#define AI_VA_REFGEN_TOGGLE           (11U)
#define AI_DIFFCLK_RPTR_TOGGLE        (12U)
#define AI_DIFFCLK_ROOT_TOGGLE        (13U)
#define AI_DIFFCLK_TERM_TOGGLE        (14U)
#define AI_DIFFCLK_RPTR1_TOGGLE       (15U)
#define AI_PHY_PLL0_TOGGLE            (16U)
#define AI_PHY_PLL1_TOGGLE            (17U)
#define AI_PHY_LDO0_TOGGLE            (18U)
#define AI_PHY_LDO1_TOGGLE            (19U)
#define AI_PHY_LVDS_TRANS_TOGGLE      (20U)
#define AI_PHY_BANDGAP_REF_TOGGLE     (21U)
#define AI_PHY_VA_REFGEN_TOGGLE       (22U)
#define AI_PHY_DIFFCLK_RPTR_TOGGLE    (23U)
#define AI_PHY_DIFFCLK_ROOT0_TOGGLE   (24U)
#define AI_PHY_DIFFCLK_ROOT1_TOGGLE   (25U)
#define AI_PHY_DIFFCLK_ROOT2_TOGGLE   (26U)
#define AI_PHY_DIFFCLK_TERM0_TOGGLE   (27U)
#define AI_PHY_DIFFCLK_TERM1_TOGGLE   (28U)
#define AI_PHY_DIFFCLK_TERM2_TOGGLE   (29U)
#define AI_PHY_DIFFCLK_TERM3_TOGGLE   (30U)
#define AI_PHY_LDO2_TOGGLE            (31U)


// Generic AI

#define AI_GENERIC_CTRL0_ADDR                     (0x0000U)
#define AI_GENERIC_CTRL0_SET_ADDR                 (0x0004U)
#define AI_GENERIC_CTRL0_CLEAR_ADDR               (0x0008U)
#define AI_GENERIC_CTRL0_TOGGLE_ADDR              (0x000cU)
#define AI_GENERIC_CTRL1_ADDR                     (0x0010U)
#define AI_GENERIC_CTRL1_SET_ADDR                 (0x0014U)
#define AI_GENERIC_CTRL1_CLEAR_ADDR               (0x0018U)
#define AI_GENERIC_CTRL1_TOGGLE_ADDR              (0x001cU)
#define AI_GENERIC_CTRL2_ADDR                     (0x0020U)
#define AI_GENERIC_CTRL2_SET_ADDR                 (0x0024U)
#define AI_GENERIC_CTRL2_CLEAR_ADDR               (0x0028U)
#define AI_GENERIC_CTRL2_TOGGLE_ADDR              (0x002cU)
#define AI_GENERIC_CTRL3_ADDR                     (0x0030U)
#define AI_GENERIC_CTRL3_SET_ADDR                 (0x0034U)
#define AI_GENERIC_CTRL3_CLEAR_ADDR               (0x0038U)
#define AI_GENERIC_CTRL3_TOGGLE_ADDR              (0x003cU)
#define AI_GENERIC_CTRL4_ADDR                     (0x0040U)
#define AI_GENERIC_CTRL4_SET_ADDR                 (0x0044U)
#define AI_GENERIC_CTRL4_CLEAR_ADDR               (0x0048U)
#define AI_GENERIC_CTRL4_TOGGLE_ADDR              (0x004cU)
#define AI_GENERIC_STAT0_ADDR                     (0x0050U)
#define AI_GENERIC_STAT1_ADDR                     (0x0060U)
#define AI_GENERIC_STAT2_ADDR                     (0x0070U)

#define AI_HP_PLL_CTRL0_ADDR                      (AI_GENERIC_CTRL0_ADDR)
#define AI_HP_PLL_CTRL0_SET_ADDR                  (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_HP_PLL_CTRL0_CLEAR_ADDR                (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_HP_PLL_CTRL0_TOGGLE_ADDR               (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_HP_PLL_STAT0_ADDR                      (AI_GENERIC_STAT0_ADDR)

#define AI_OSC24M_CTRLOSC_ADDR                    (AI_GENERIC_CTRL0_ADDR)
#define AI_OSC24M_CTRLOSC_SET_ADDR                (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_OSC24M_CTRLOSC_CLEAR_ADDR              (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_OSC24M_CTRLOSC_TOGGLE_ADDR             (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_OSC24M_STATOSC_ADDR                    (AI_GENERIC_STAT0_ADDR)
#define AI_OSC24M_STAT0_ADDR                      (AI_GENERIC_STAT0_ADDR)

#define AI_RC200OSC_CTRL0_ADDR                    (AI_GENERIC_CTRL0_ADDR)
#define AI_RC200OSC_CTRL0_SET_ADDR                (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_RC200OSC_CTRL0_CLEAR_ADDR              (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_RC200OSC_CTRL0_TOGGLE_ADDR             (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_RC200OSC_CTRL1_ADDR                    (AI_GENERIC_CTRL1_ADDR)
#define AI_RC200OSC_CTRL1_SET_ADDR                (AI_GENERIC_CTRL1_SET_ADDR)
#define AI_RC200OSC_CTRL1_CLEAR_ADDR              (AI_GENERIC_CTRL1_CLEAR_ADDR)
#define AI_RC200OSC_CTRL1_TOGGLE_ADDR             (AI_GENERIC_CTRL1_TOGGLE_ADDR)
#define AI_RC200OSC_CTRL2_ADDR                    (AI_GENERIC_CTRL2_ADDR)
#define AI_RC200OSC_CTRL2_SET_ADDR                (AI_GENERIC_CTRL2_SET_ADDR)
#define AI_RC200OSC_CTRL2_CLEAR_ADDR              (AI_GENERIC_CTRL2_CLEAR_ADDR)
#define AI_RC200OSC_CTRL2_TOGGLE_ADDR             (AI_GENERIC_CTRL2_TOGGLE_ADDR)
#define AI_RC200OSC_CTRL3_ADDR                    (AI_GENERIC_CTRL3_ADDR)
#define AI_RC200OSC_CTRL3_SET_ADDR                (AI_GENERIC_CTRL3_SET_ADDR)
#define AI_RC200OSC_CTRL3_CLEAR_ADDR              (AI_GENERIC_CTRL3_CLEAR_ADDR)
#define AI_RC200OSC_CTRL3_TOGGLE_ADDR             (AI_GENERIC_CTRL3_TOGGLE_ADDR)
#define AI_RC200OSC_CTRL4_ADDR                    (AI_GENERIC_CTRL4_ADDR)
#define AI_RC200OSC_CTRL4_SET_ADDR                (AI_GENERIC_CTRL4_SET_ADDR)
#define AI_RC200OSC_CTRL4_CLEAR_ADDR              (AI_GENERIC_CTRL4_CLEAR_ADDR)
#define AI_RC200OSC_CTRL4_TOGGLE_ADDR             (AI_GENERIC_CTRL4_TOGGLE_ADDR)
#define AI_RC200OSC_STAT0_ADDR                    (AI_GENERIC_STAT0_ADDR)
#define AI_RC200OSC_STAT1_ADDR                    (AI_GENERIC_STAT1_ADDR)
#define AI_RC200OSC_STAT2_ADDR                    (AI_GENERIC_STAT2_ADDR)

#define AI_LVDS_TRANS_CTRL0_ADDR                  (AI_GENERIC_CTRL0_ADDR)
#define AI_LVDS_TRANS_CTRL0_SET_ADDR              (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_LVDS_TRANS_CTRL0_CLEAR_ADDR            (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_LVDS_TRANS_CTRL0_TOGGLE_ADDR           (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_LVDS_TRANS_STAT0_ADDR                  (AI_GENERIC_STAT0_ADDR)

#define AI_NEG_CHARGE_PUMP_CTRL0_ADDR             (AI_GENERIC_CTRL0_ADDR)
#define AI_NEG_CHARGE_PUMP_CTRL0_SET_ADDR         (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_NEG_CHARGE_PUMP_CTRL0_CLEAR_ADDR       (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_NEG_CHARGE_PUMP_CTRL0_TOGGLE_ADDR      (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_NEG_CHARGE_PUMP_STAT0_ADDR             (AI_GENERIC_STAT0_ADDR)

#define AI_WELL_LEVEL_SOURCE_CTRL0_ADDR           (AI_GENERIC_CTRL0_ADDR)
#define AI_WELL_LEVEL_SOURCE_CTRL0_SET_ADDR       (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_WELL_LEVEL_SOURCE_CTRL0_CLEAR_ADDR     (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_WELL_LEVEL_SOURCE_CTRL0_TOGGLE_ADDR    (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_WELL_LEVEL_SOURCE_STAT0_ADDR           (AI_GENERIC_STAT0_ADDR)

#define AI_BANDGAP_REF_CTRL0_ADDR                 (AI_GENERIC_CTRL0_ADDR)
#define AI_BANDGAP_REF_CTRL0_SET_ADDR             (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_BANDGAP_REF_CTRL0_CLEAR_ADDR           (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_BANDGAP_REF_CTRL0_TOGGLE_ADDR          (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_BANDGAP_REF_STAT0_ADDR                 (AI_GENERIC_STAT0_ADDR)

#define AI_VA_REFGEN_CTRL0_ADDR                   (AI_GENERIC_CTRL0_ADDR)
#define AI_VA_REFGEN_CTRL0_SET_ADDR               (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_VA_REFGEN_CTRL0_CLEAR_ADDR             (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_VA_REFGEN_CTRL0_TOGGLE_ADDR            (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_VA_REFGEN_STAT0_ADDR                   (AI_GENERIC_STAT0_ADDR)

#define AI_DIFFCLK_RPTR_CTRL0_ADDR                (AI_GENERIC_CTRL0_ADDR)
#define AI_DIFFCLK_RPTR_CTRL0_SET_ADDR            (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_DIFFCLK_RPTR_CTRL0_CLEAR_ADDR          (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_DIFFCLK_RPTR_CTRL0_TOGGLE_ADDR         (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_DIFFCLK_RPTR_STAT0_ADDR                (AI_GENERIC_STAT0_ADDR)

#define AI_DIFFCLK_ROOT_CTRL0_ADDR                (AI_GENERIC_CTRL0_ADDR)
#define AI_DIFFCLK_ROOT_CTRL0_SET_ADDR            (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_DIFFCLK_ROOT_CTRL0_CLEAR_ADDR          (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_DIFFCLK_ROOT_CTRL0_TOGGLE_ADDR         (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_DIFFCLK_ROOT_STAT0_ADDR                (AI_GENERIC_STAT0_ADDR)

#define AI_DIFFCLK_TERM_CTRL0_ADDR                (AI_GENERIC_CTRL0_ADDR)
#define AI_DIFFCLK_TERM_CTRL0_SET_ADDR            (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_DIFFCLK_TERM_CTRL0_CLEAR_ADDR          (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_DIFFCLK_TERM_CTRL0_TOGGLE_ADDR         (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_DIFFCLK_TERM_STAT0_ADDR                (AI_GENERIC_STAT0_ADDR)

#define AI_AV_PLL_CTRL0_ADDR                      (AI_GENERIC_CTRL0_ADDR)
#define AI_AV_PLL_CTRL0_SET_ADDR                  (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_AV_PLL_CTRL0_CLEAR_ADDR                (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_AV_PLL_CTRL0_TOGGLE_ADDR               (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_AV_PLL_SPREAD_SPECTRUM_ADDR            (AI_GENERIC_CTRL1_ADDR)
#define AI_AV_PLL_SPREAD_SPECTRUM_SET_ADDR        (AI_GENERIC_CTRL1_SET_ADDR)
#define AI_AV_PLL_SPREAD_SPECTRUM_CLEAR_ADDR      (AI_GENERIC_CTRL1_CLEAR_ADDR)
#define AI_AV_PLL_SPREAD_SPECTRUM_TOGGLE_ADDR     (AI_GENERIC_CTRL1_TOGGLE_ADDR)
#define AI_AV_PLL_NUMERATOR_ADDR                  (AI_GENERIC_CTRL2_ADDR)
#define AI_AV_PLL_NUMERATOR_SET_ADDR              (AI_GENERIC_CTRL2_SET_ADDR)
#define AI_AV_PLL_NUMERATOR_CLEAR_ADDR            (AI_GENERIC_CTRL2_CLEAR_ADDR)
#define AI_AV_PLL_NUMERATOR_TOGGLE_ADDR           (AI_GENERIC_CTRL2_TOGGLE_ADDR)
#define AI_AV_PLL_DENOMINATOR_ADDR                (AI_GENERIC_CTRL3_ADDR)
#define AI_AV_PLL_DENOMINATOR_SET_ADDR            (AI_GENERIC_CTRL3_SET_ADDR)
#define AI_AV_PLL_DENOMINATOR_CLEAR_ADDR          (AI_GENERIC_CTRL3_CLEAR_ADDR)
#define AI_AV_PLL_DENOMINATOR_TOGGLE_ADDR         (AI_GENERIC_CTRL3_TOGGLE_ADDR)
#define AI_AV_PLL_CTRL4_ADDR                      (AI_GENERIC_CTRL4_ADDR)
#define AI_AV_PLL_CTRL4_SET_ADDR                  (AI_GENERIC_CTRL4_SET_ADDR)
#define AI_AV_PLL_CTRL4_CLEAR_ADDR                (AI_GENERIC_CTRL4_CLEAR_ADDR)
#define AI_AV_PLL_CTRL4_TOGGLE_ADDR               (AI_GENERIC_CTRL4_TOGGLE_ADDR)
#define AI_AV_PLL_STAT0_ADDR                      (AI_GENERIC_STAT0_ADDR)
#define AI_AV_PLL_STAT1_ADDR                      (AI_GENERIC_STAT1_ADDR)
#define AI_AV_PLL_STAT2_ADDR                      (AI_GENERIC_STAT2_ADDR)

#define AI_MLB_PLL_CTRL0_ADDR                     (AI_GENERIC_CTRL0_ADDR)
#define AI_MLB_PLL_CTRL0_SET_ADDR                 (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_MLB_PLL_CTRL0_CLEAR_ADDR               (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_MLB_PLL_CTRL0_TOGGLE_ADDR              (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_MLB_PLL_STAT0_ADDR                     (AI_GENERIC_STAT0_ADDR)

#define AI_PHY_LDO_CTRL0_ADDR                     (AI_GENERIC_CTRL0_ADDR)
#define AI_PHY_LDO_CTRL0_SET_ADDR                 (AI_GENERIC_CTRL0_SET_ADDR)
#define AI_PHY_LDO_CTRL0_CLEAR_ADDR               (AI_GENERIC_CTRL0_CLEAR_ADDR)
#define AI_PHY_LDO_CTRL0_TOGGLE_ADDR              (AI_GENERIC_CTRL0_TOGGLE_ADDR)
#define AI_PHY_LDO_STAT0_ADDR                     (AI_GENERIC_STAT0_ADDR)


// Custom AI

#define AI_DIG_PLL_DIV_CTRL_ADDR                  (0x0000U)
#define AI_DIG_PLL_MFN_ADDR                       (0x0004U)
#define AI_DIG_PLL_MFD_ADDR                       (0x0008U)
#define AI_DIG_PLL_SSC_ADDR                       (0x000cU)
#define AI_DIG_PLL_LPF_CTRL_ADDR                  (0x0010U)
#define AI_DIG_PLL_LPF_CTRL_SET_ADDR              (0x0014U)
#define AI_DIG_PLL_LPF_CTRL_CLR_ADDR              (0x0018U)
#define AI_DIG_PLL_LPF_CTRL_TOG_ADDR              (0x001cU)
#define AI_DIG_PLL_DCO_CTRL_ADDR                  (0x0020U)
#define AI_DIG_PLL_DCO_CTRL_SET_ADDR              (0x0024U)
#define AI_DIG_PLL_DCO_CTRL_CLR_ADDR              (0x0028U)
#define AI_DIG_PLL_DCO_CTRL_TOG_ADDR              (0x002cU)
#define AI_DIG_PLL_CTRL_ADDR                      (0x0030U)
#define AI_DIG_PLL_CTRL_SET_ADDR                  (0x0034U)
#define AI_DIG_PLL_CTRL_CLR_ADDR                  (0x0038U)
#define AI_DIG_PLL_CTRL_TOG_ADDR                  (0x003cU)
#define AI_DIG_PLL_CTRL2_ADDR                     (0x0040U)
#define AI_DIG_PLL_CTRL2_SET_ADDR                 (0x0044U)
#define AI_DIG_PLL_CTRL2_CLR_ADDR                 (0x0048U)
#define AI_DIG_PLL_CTRL2_TOG_ADDR                 (0x004cU)
#define AI_DIG_PLL_CTRL3_ADDR                     (0x0050U)
#define AI_DIG_PLL_CTRL3_SET_ADDR                 (0x0054U)
#define AI_DIG_PLL_CTRL3_CLR_ADDR                 (0x0058U)
#define AI_DIG_PLL_CTRL3_TOG_ADDR                 (0x005cU)
#define AI_DIG_PLL_STATUS_ADDR                    (0x0060U)
#define AI_DIG_PLL_SPARE_ADDR                     (0x0070U)

#define AI_DIG_PLL_DIV_CTRL_RESET                 (0x00000028U)
#define AI_DIG_PLL_MFN_RESET                      (0x00000000U)
#define AI_DIG_PLL_MFD_RESET                      (0x0000ffffU)
#define AI_DIG_PLL_SSC_RESET                      (0x00000000U)
#define AI_DIG_PLL_LPF_CTRL_RESET                 (0x10005026U)
#define AI_DIG_PLL_DCO_CTRL_RESET                 (0x0400c040U)
#define AI_DIG_PLL_CTRL_RESET                     (0x0f040000U)
#define AI_DIG_PLL_CTRL2_RESET                    (0x00030400U)
#define AI_DIG_PLL_CTRL3_RESET                    (0x01000100U)
#define AI_DIG_PLL_STATUS_RESET                   (0x00000000U)

#define AI_DIG_PLL_DIV_CTRL_MASK                  (0x0000007fU)
#define AI_DIG_PLL_MFN_MASK                       (0x3fffffffU)
#define AI_DIG_PLL_MFD_MASK                       (0x3fffffffU)
#define AI_DIG_PLL_SSC_MASK                       (0x00ffffffU)
#define AI_DIG_PLL_LPF_CTRL_MASK                  (0xfffff777U)
#define AI_DIG_PLL_DCO_CTRL_MASK                  (0xff01ff7fU)
#define AI_DIG_PLL_CTRL_MASK                      (0xffffffffU)
#define AI_DIG_PLL_CTRL2_MASK                     (0x7ff7ffffU)
#define AI_DIG_PLL_CTRL3_MASK                     (0xf9c0ffffU)
#define AI_DIG_PLL_STATUS_MASK                    (0x01ff7f0fU)

#define AI_VDROP_PROCMON_CTRL0_ADDR                           (0x0000U)
#define AI_VDROP_PROCMON_CTRL0_SET_ADDR                       (0x0004U)
#define AI_VDROP_PROCMON_CTRL0_CLEAR_ADDR                     (0x0008U)
#define AI_VDROP_PROCMON_CTRL0_TOGGLE_ADDR                    (0x000cU)
#define AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_ADDR              (0x0010U)
#define AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_SET_ADDR          (0x0014U)
#define AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_CLEAR_ADDR        (0x0018U)
#define AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_TOGGLE_ADDR       (0x001cU)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADDR                 (0x0020U)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_SET_ADDR             (0x0024U)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_CLEAR_ADDR           (0x0028U)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_TOGGLE_ADDR          (0x002cU)
#define AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_ADDR            (0x0030U)
#define AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_SET_ADDR        (0x0034U)
#define AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_CLEAR_ADDR      (0x0038U)
#define AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_TOGGLE_ADDR     (0x003cU)
#define AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_ADDR            (0x0040U)
#define AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_SET_ADDR        (0x0044U)
#define AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_CLEAR_ADDR      (0x0048U)
#define AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_TOGGLE_ADDR     (0x004cU)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_ADDR                   (0x0050U)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_SET_ADDR               (0x0054U)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_CLEAR_ADDR             (0x0058U)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_TOGGLE_ADDR            (0x005cU)
#define AI_VDROP_PROCMON_DEBUG_STATUS_ADDR                    (0x0060U)

#define AI_TEMP_SENSE_CTRL0_ADDR                  (0x0000U)
#define AI_TEMP_SENSE_CTRL0_SET_ADDR              (0x0004U)
#define AI_TEMP_SENSE_CTRL0_CLEAR_ADDR            (0x0008U)
#define AI_TEMP_SENSE_CTRL0_TOGGLE_ADDR           (0x000cU)
#define AI_TEMP_SENSE_CTRL1_ADDR                  (0x0010U)
#define AI_TEMP_SENSE_CTRL1_SET_ADDR              (0x0014U)
#define AI_TEMP_SENSE_CTRL1_CLEAR_ADDR            (0x0018U)
#define AI_TEMP_SENSE_CTRL1_TOGGLE_ADDR           (0x001cU)
#define AI_TEMP_SENSE_RANGE0_ADDR                 (0x0020U)
#define AI_TEMP_SENSE_RANGE0_SET_ADDR             (0x0024U)
#define AI_TEMP_SENSE_RANGE0_CLEAR_ADDR           (0x0028U)
#define AI_TEMP_SENSE_RANGE0_TOGGLE_ADDR          (0x002cU)
#define AI_TEMP_SENSE_RANGE1_ADDR                 (0x0030U)
#define AI_TEMP_SENSE_RANGE1_SET_ADDR             (0x0034U)
#define AI_TEMP_SENSE_RANGE1_CLEAR_ADDR           (0x0038U)
#define AI_TEMP_SENSE_RANGE1_TOGGLE_ADDR          (0x003cU)
#define AI_TEMP_SENSE_OFFSET_COMP_ADDR            (0x0040U)
#define AI_TEMP_SENSE_OFFSET_COMP_SET_ADDR        (0x0044U)
#define AI_TEMP_SENSE_OFFSET_COMP_CLEAR_ADDR      (0x0048U)
#define AI_TEMP_SENSE_OFFSET_COMP_TOGGLE_ADDR     (0x004cU)
#define AI_TEMP_SENSE_STATUS0_ADDR                (0x0050U)
#define AI_TEMP_SENSE_STATUS0_SET_ADDR            (0x0054U)
#define AI_TEMP_SENSE_STATUS0_CLEAR_ADDR          (0x0058U)
#define AI_TEMP_SENSE_STATUS0_TOGGLE_ADDR         (0x005cU)

// AI Registers

#define AI_DIG_PLL_DIV_CTRL_MFI_MASK     (0x7FU)
#define AI_DIG_PLL_DIV_CTRL_MFI_SHIFT    (0U)
#define AI_DIG_PLL_DIV_CTRL_MFI(x)       (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_DIV_CTRL_MFI_SHIFT)) & AI_DIG_PLL_DIV_CTRL_MFI_MASK)
#define AI_DIG_PLL_MFN_VALUE_MASK        (0x3FFFFFFFU)
#define AI_DIG_PLL_MFN_VALUE_SHIFT       (0U)
#define AI_DIG_PLL_MFN_VALUE(x)          (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_MFN_VALUE_SHIFT)) & AI_DIG_PLL_MFN_VALUE_MASK)
#define AI_DIG_PLL_MFD_VALUE_MASK        (0x3FFFFFFFU)
#define AI_DIG_PLL_MFD_VALUE_SHIFT       (0U)
#define AI_DIG_PLL_MFD_VALUE(x)          (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_MFD_VALUE_SHIFT)) & AI_DIG_PLL_MFD_VALUE_MASK)
#define AI_DIG_PLL_SSC_STEP_MASK         (0xFFFU)
#define AI_DIG_PLL_SSC_STEP_SHIFT        (0U)
#define AI_DIG_PLL_SSC_STEP(x)           (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_SSC_STEP_SHIFT)) & AI_DIG_PLL_SSC_STEP_MASK)
#define AI_DIG_PLL_SSC_STOP_MASK         (0xFFF000U)
#define AI_DIG_PLL_SSC_STOP_SHIFT        (12U)
#define AI_DIG_PLL_SSC_STOP(x)           (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_SSC_STOP_SHIFT)) & AI_DIG_PLL_SSC_STOP_MASK)
#define AI_DIG_PLL_LPF_CTRL_KP_MASK      (0x7U)
#define AI_DIG_PLL_LPF_CTRL_KP_SHIFT     (0U)
#define AI_DIG_PLL_LPF_CTRL_KP(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_LPF_CTRL_KP_SHIFT)) & AI_DIG_PLL_LPF_CTRL_KP_MASK)
#define AI_DIG_PLL_LPF_CTRL_KI_MASK      (0x70U)
#define AI_DIG_PLL_LPF_CTRL_KI_SHIFT     (4U)
#define AI_DIG_PLL_LPF_CTRL_KI(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_LPF_CTRL_KI_SHIFT)) & AI_DIG_PLL_LPF_CTRL_KI_MASK)
#define AI_DIG_PLL_LPF_CTRL_KD_MASK      (0x700U)
#define AI_DIG_PLL_LPF_CTRL_KD_SHIFT     (8U)
#define AI_DIG_PLL_LPF_CTRL_KD(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_LPF_CTRL_KD_SHIFT)) & AI_DIG_PLL_LPF_CTRL_KD_MASK)
#define AI_DIG_PLL_LPF_CTRL_KN_MASK      (0xf000U)
#define AI_DIG_PLL_LPF_CTRL_KN_SHIFT     (12U)
#define AI_DIG_PLL_LPF_CTRL_KN(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_LPF_CTRL_KN_SHIFT)) & AI_DIG_PLL_LPF_CTRL_KN_MASK)
#define AI_DIG_PLL_LPF_CTRL_FLOCK_BYP_MASK (0x10000U)
#define AI_DIG_PLL_LPF_CTRL_FLOCK_BYP_SHIFT (16U)
#define AI_DIG_PLL_LPF_CTRL_FLOCK_BYP(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_LPF_CTRL_FLOCK_BYP_SHIFT)) & AI_DIG_PLL_LPF_CTRL_FLOCK_BYP_MASK)
#define AI_DIG_PLL_LPF_CTRL_KE_MASK      (0x60000U)
#define AI_DIG_PLL_LPF_CTRL_KE_SHIFT     (17U)
#define AI_DIG_PLL_LPF_CTRL_KE(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_LPF_CTRL_KE_SHIFT)) & AI_DIG_PLL_LPF_CTRL_KE_MASK)
#define AI_DIG_PLL_LPF_CTRL_KC_MASK      (0x7FF80000U)
#define AI_DIG_PLL_LPF_CTRL_KC_SHIFT     (19U)
#define AI_DIG_PLL_LPF_CTRL_KC(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_LPF_CTRL_KC_SHIFT)) & AI_DIG_PLL_LPF_CTRL_KC_MASK)
#define AI_DIG_PLL_LPF_CTRL_FINE_PLOCK_MASK (0x80000000U)
#define AI_DIG_PLL_LPF_CTRL_FINE_PLOCK_SHIFT (31U)
#define AI_DIG_PLL_LPF_CTRL_FINE_PLOCK(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_LPF_CTRL_FINE_PLOCK_SHIFT)) & AI_DIG_PLL_LPF_CTRL_FINE_PLOCK_MASK)
#define AI_DIG_PLL_DCO_CTRL_FC_DS_MASK   (0x7FU)
#define AI_DIG_PLL_DCO_CTRL_FC_DS_SHIFT  (0U)
#define AI_DIG_PLL_DCO_CTRL_FC_DS(x)     (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_DCO_CTRL_FC_DS_SHIFT)) & AI_DIG_PLL_DCO_CTRL_FC_DS_MASK)
#define AI_DIG_PLL_DCO_CTRL_FC_UFINE_MASK (0x1FF00U)
#define AI_DIG_PLL_DCO_CTRL_FC_UFINE_SHIFT (8U)
#define AI_DIG_PLL_DCO_CTRL_FC_UFINE(x)   (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_DCO_CTRL_FC_UFINE_SHIFT)) & AI_DIG_PLL_DCO_CTRL_FC_UFINE_MASK)
#define AI_DIG_PLL_DCO_CTRL_DCO_PC_MASK  (0x7F000000U)
#define AI_DIG_PLL_DCO_CTRL_DCO_PC_SHIFT (24U)
#define AI_DIG_PLL_DCO_CTRL_DCO_PC(x)    (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_DCO_CTRL_DCO_PC_SHIFT)) & AI_DIG_PLL_DCO_CTRL_DCO_PC_MASK)
#define AI_DIG_PLL_DCO_CTRL_OVERRIDE_MASK (0x80000000U)
#define AI_DIG_PLL_DCO_CTRL_OVERRIDE_SHIFT (31U)
#define AI_DIG_PLL_DCO_CTRL_OVERRIDE(x)  (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_DCO_CTRL_OVERRIDE_SHIFT)) & AI_DIG_PLL_DCO_CTRL_OVERRIDE_MASK)
#define AI_DIG_PLL_CTRL_DPLL_CLK_EN_MASK (0x1U)
#define AI_DIG_PLL_CTRL_DPLL_CLK_EN_SHIFT (0U)
#define AI_DIG_PLL_CTRL_DPLL_CLK_EN(x)   (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_DPLL_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_DPLL_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_DPLL_DIV_2_CLK_EN_MASK (0x2U)
#define AI_DIG_PLL_CTRL_DPLL_DIV_2_CLK_EN_SHIFT (1U)
#define AI_DIG_PLL_CTRL_DPLL_DIV_2_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_DPLL_DIV_2_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_DPLL_DIV_2_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_DPLL_DIV_4_CLK_EN_MASK (0x4U)
#define AI_DIG_PLL_CTRL_DPLL_DIV_4_CLK_EN_SHIFT (2U)
#define AI_DIG_PLL_CTRL_DPLL_DIV_4_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_DPLL_DIV_4_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_DPLL_DIV_4_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_DCO_CLK_EN_MASK (0x8U)
#define AI_DIG_PLL_CTRL_DCO_CLK_EN_SHIFT (3U)
#define AI_DIG_PLL_CTRL_DCO_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_DCO_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_DCO_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_PLL_TEST_MASK    (0xFF0U)
#define AI_DIG_PLL_CTRL_PLL_TEST_SHIFT   (4U)
#define AI_DIG_PLL_CTRL_PLL_TEST(x)      (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_PLL_TEST_SHIFT)) & AI_DIG_PLL_CTRL_PLL_TEST_MASK)
#define AI_DIG_PLL_CTRL_DCO_VCHP_DLY_MASK    (0xF000U)
#define AI_DIG_PLL_CTRL_DCO_VCHP_DLY_SHIFT   (12U)
#define AI_DIG_PLL_CTRL_DCO_VCHP_DLY(x)      (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_DCO_VCHP_DLY_SHIFT)) & AI_DIG_PLL_CTRL_DCO_VCHP_DLY_MASK)
#define AI_DIG_PLL_CTRL_REF_CLK_CNTR_MASK (0xF0000U)
#define AI_DIG_PLL_CTRL_REF_CLK_CNTR_SHIFT (16U)
#define AI_DIG_PLL_CTRL_REF_CLK_CNTR(x)  (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_REF_CLK_CNTR_SHIFT)) & AI_DIG_PLL_CTRL_REF_CLK_CNTR_MASK)
#define AI_DIG_PLL_CTRL_COARSE_BIT_DLY_MASK (0x3FF00000U)
#define AI_DIG_PLL_CTRL_COARSE_BIT_DLY_SHIFT (20U)
#define AI_DIG_PLL_CTRL_COARSE_BIT_DLY(x)  (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_COARSE_BIT_DLY_SHIFT)) & AI_DIG_PLL_CTRL_COARSE_BIT_DLY_MASK)
#define AI_DIG_PLL_CTRL_ENABLE_MASK      (0x40000000U)
#define AI_DIG_PLL_CTRL_ENABLE_SHIFT     (30U)
#define AI_DIG_PLL_CTRL_ENABLE(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_ENABLE_SHIFT)) & AI_DIG_PLL_CTRL_ENABLE_MASK)
#define AI_DIG_PLL_CTRL_START_MASK       (0x80000000U)
#define AI_DIG_PLL_CTRL_START_SHIFT      (31U)
#define AI_DIG_PLL_CTRL_START(x)         (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_START_SHIFT)) & AI_DIG_PLL_CTRL_START_MASK)

#define AI_DIG_PLL_CTRL_SET_DPLL_CLK_EN_MASK (0x1U)
#define AI_DIG_PLL_CTRL_SET_DPLL_CLK_EN_SHIFT (0U)
#define AI_DIG_PLL_CTRL_SET_DPLL_CLK_EN(x)   (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_SET_DPLL_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_SET_DPLL_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_SET_DPLL_DIV_2_CLK_EN_MASK (0x2U)
#define AI_DIG_PLL_CTRL_SET_DPLL_DIV_2_CLK_EN_SHIFT (1U)
#define AI_DIG_PLL_CTRL_SET_DPLL_DIV_2_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_SET_DPLL_DIV_2_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_SET_DPLL_DIV_2_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_SET_DPLL_DIV_4_CLK_EN_MASK (0x4U)
#define AI_DIG_PLL_CTRL_SET_DPLL_DIV_4_CLK_EN_SHIFT (2U)
#define AI_DIG_PLL_CTRL_SET_DPLL_DIV_4_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_SET_DPLL_DIV_4_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_SET_DPLL_DIV_4_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_SET_DCO_CLK_EN_MASK (0x8U)
#define AI_DIG_PLL_CTRL_SET_DCO_CLK_EN_SHIFT (3U)
#define AI_DIG_PLL_CTRL_SET_DCO_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_SET_DCO_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_SET_DCO_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_SET_ENABLE_MASK      (0x40000000U)
#define AI_DIG_PLL_CTRL_SET_ENABLE_SHIFT     (30U)
#define AI_DIG_PLL_CTRL_SET_ENABLE(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_SET_ENABLE_SHIFT)) & AI_DIG_PLL_CTRL_SET_ENABLE_MASK)
#define AI_DIG_PLL_CTRL_SET_START_MASK       (0x80000000U)
#define AI_DIG_PLL_CTRL_SET_START_SHIFT      (31U)
#define AI_DIG_PLL_CTRL_SET_START(x)         (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_SET_START_SHIFT)) & AI_DIG_PLL_CTRL_SET_START_MASK)

#define AI_DIG_PLL_CTRL_CLR_DPLL_CLK_EN_MASK (0x1U)
#define AI_DIG_PLL_CTRL_CLR_DPLL_CLK_EN_SHIFT (0U)
#define AI_DIG_PLL_CTRL_CLR_DPLL_CLK_EN(x)   (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_CLR_DPLL_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_CLR_DPLL_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_CLR_DPLL_DIV_2_CLK_EN_MASK (0x2U)
#define AI_DIG_PLL_CTRL_CLR_DPLL_DIV_2_CLK_EN_SHIFT (1U)
#define AI_DIG_PLL_CTRL_CLR_DPLL_DIV_2_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_CLR_DPLL_DIV_2_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_CLR_DPLL_DIV_2_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_CLR_DPLL_DIV_4_CLK_EN_MASK (0x4U)
#define AI_DIG_PLL_CTRL_CLR_DPLL_DIV_4_CLK_EN_SHIFT (2U)
#define AI_DIG_PLL_CTRL_CLR_DPLL_DIV_4_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_CLR_DPLL_DIV_4_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_CLR_DPLL_DIV_4_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_CLR_DCO_CLK_EN_MASK (0x8U)
#define AI_DIG_PLL_CTRL_CLR_DCO_CLK_EN_SHIFT (3U)
#define AI_DIG_PLL_CTRL_CLR_DCO_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_CLR_DCO_CLK_EN_SHIFT)) & AI_DIG_PLL_CTRL_CLR_DCO_CLK_EN_MASK)
#define AI_DIG_PLL_CTRL_CLR_ENABLE_MASK      (0x40000000U)
#define AI_DIG_PLL_CTRL_CLR_ENABLE_SHIFT     (30U)
#define AI_DIG_PLL_CTRL_CLR_ENABLE(x)        (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_CLR_ENABLE_SHIFT)) & AI_DIG_PLL_CTRL_CLR_ENABLE_MASK)
#define AI_DIG_PLL_CTRL_CLR_START_MASK       (0x80000000U)
#define AI_DIG_PLL_CTRL_CLR_START_SHIFT      (31U)
#define AI_DIG_PLL_CTRL_CLR_START(x)         (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL_CLR_START_SHIFT)) & AI_DIG_PLL_CTRL_CLR_START_MASK)



#define AI_DIG_PLL_CTRL2_EN_TRACKING_MASK    (0x1U)
#define AI_DIG_PLL_CTRL2_EN_TRACKING_SHIFT   (0U)
#define AI_DIG_PLL_CTRL2_EN_TRACKING(x)      (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL2_EN_TRACKING_SHIFT)) & AI_DIG_PLL_CTRL2_EN_TRACKING_MASK)
#define AI_DIG_PLL_CTRL2_FC_CNT_MASK    (0x7FEU)
#define AI_DIG_PLL_CTRL2_FC_CNT_SHIFT   (1U)
#define AI_DIG_PLL_CTRL2_FC_CNT(x)      (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL2_FC_CNT_SHIFT)) & AI_DIG_PLL_CTRL2_FC_CNT_MASK)
#define AI_DIG_PLL_CTRL2_FC_THRESH_MASK    (0x7F800U)
#define AI_DIG_PLL_CTRL2_FC_THRESH_SHIFT   (11U)
#define AI_DIG_PLL_CTRL2_FC_THRESH(x)      (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL2_FC_THRESH_SHIFT)) & AI_DIG_PLL_CTRL2_FC_THRESH_MASK)
#define AI_DIG_PLL_CTRL2_KE1_MASK    (0x700000U)
#define AI_DIG_PLL_CTRL2_KE1_SHIFT   (20U)
#define AI_DIG_PLL_CTRL2_KE1(x)      (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL2_KE1_SHIFT)) & AI_DIG_PLL_CTRL2_KE1_MASK)
#define AI_DIG_PLL_CTRL2_KE2_MASK    (0x3800000U)
#define AI_DIG_PLL_CTRL2_KE2_SHIFT   (23U)
#define AI_DIG_PLL_CTRL2_KE2(x)      (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL2_KE2_SHIFT)) & AI_DIG_PLL_CTRL2_KE2_MASK)
#define AI_DIG_PLL_CTRL2_KE3_MASK    (0x1C000000U)
#define AI_DIG_PLL_CTRL2_KE3_SHIFT   (26U)
#define AI_DIG_PLL_CTRL2_KE3(x)      (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL2_KE3_SHIFT)) & AI_DIG_PLL_CTRL2_KE3_MASK)
#define AI_DIG_PLL_CTRL2_DITHER_EN_MASK (0x20000000U)
#define AI_DIG_PLL_CTRL2_DITHER_EN_SHIFT (29U)
#define AI_DIG_PLL_CTRL2_DITHER_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL2_DITHER_EN_SHIFT)) & AI_DIG_PLL_CTRL2_DITHER_EN_MASK)
#define AI_DIG_PLL_CTRL2_SSC_EN_MASK (0x40000000U)
#define AI_DIG_PLL_CTRL2_SSC_EN_SHIFT (30U)
#define AI_DIG_PLL_CTRL2_SSC_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL2_SSC_EN_SHIFT)) & AI_DIG_PLL_CTRL2_SSC_EN_MASK)

#define AI_DIG_PLL_CTRL3_COARSE_CNT_MASK (0xFFFFU)
#define AI_DIG_PLL_CTRL3_COARSE_CNT_SHIFT (0U)
#define AI_DIG_PLL_CTRL3_COARSE_CNT(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL3_COARSE_CNT_SHIFT)) & AI_DIG_PLL_CTRL3_COARSE_CNT_MASK)
#define AI_DIG_PLL_CTRL3_COARSE_ADJ_STEP_MASK (0x1C00000U)
#define AI_DIG_PLL_CTRL3_COARSE_ADJ_STEP_SHIFT (22U)
#define AI_DIG_PLL_CTRL3_COARSE_ADJ_STEP(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL3_COARSE_ADJ_STEP_SHIFT)) & AI_DIG_PLL_CTRL3_COARSE_ADJ_STEP_MASK)
#define AI_DIG_PLL_CTRL3_TEST_MASK (0xF8000000U)
#define AI_DIG_PLL_CTRL3_TEST_SHIFT (27U)
#define AI_DIG_PLL_CTRL3_TEST(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL3_TEST_SHIFT)) & AI_DIG_PLL_CTRL3_TEST_MASK)

#define AI_DIG_PLL_CTRL3_TEST_BIT0_MASK (0x08000000U)
#define AI_DIG_PLL_CTRL3_TEST_BIT0_SHIFT (27U)
#define AI_DIG_PLL_CTRL3_TEST_BIT0(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL3_TEST_BIT0_SHIFT)) & AI_DIG_PLL_CTRL3_TEST_BIT0_MASK)
#define AI_DIG_PLL_CTRL3_TEST_BIT1_MASK (0x10000000U)
#define AI_DIG_PLL_CTRL3_TEST_BIT1_SHIFT (28U)
#define AI_DIG_PLL_CTRL3_TEST_BIT1(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL3_TEST_BIT1_SHIFT)) & AI_DIG_PLL_CTRL3_TEST_BIT1_MASK)
#define AI_DIG_PLL_CTRL3_TEST_BIT2_MASK (0x20000000U)
#define AI_DIG_PLL_CTRL3_TEST_BIT2_SHIFT (29U)
#define AI_DIG_PLL_CTRL3_TEST_BIT2(x) (((uint32_t)(((uint32_t)(x)) << AI_DIG_PLL_CTRL3_TEST_BIT2_SHIFT)) & AI_DIG_PLL_CTRL3_TEST_BIT2_MASK)

#define AI_DIG_PLL_STATUS_FLOCK_MASK     (0x1U)
#define AI_DIG_PLL_STATUS_FLOCK_SHIFT    (0U)
#define AI_DIG_PLL_STATUS_FLOCK(x)       ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_STATUS_FLOCK_MASK) >> AI_DIG_PLL_STATUS_FLOCK_SHIFT))
#define AI_DIG_PLL_STATUS_PLOCK_MASK     (0x2U)
#define AI_DIG_PLL_STATUS_PLOCK_SHIFT    (1U)
#define AI_DIG_PLL_STATUS_PLOCK(x)       ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_STATUS_PLOCK_MASK) >> AI_DIG_PLL_STATUS_PLOCK_SHIFT))
#define AI_DIG_PLL_STATUS_S1_OVERFLOW_FLAG_MASK     (0x4U)
#define AI_DIG_PLL_STATUS_S1_OVERFLOW_FLAG_SHIFT    (2U)
#define AI_DIG_PLL_STATUS_S1_OVERFLOW_FLAG_FLAG(x)       ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_STATUS_S1_OVERFLOW_FLAG_MASK) >> AI_DIG_PLL_STATUS_S1_OVERFLOW_FLAG_SHIFT))
#define AI_DIG_PLL_STATUS_S1_UNDERFLOW_FLAG_MASK     (0x8U)
#define AI_DIG_PLL_STATUS_S1_UNDERFLOW_FLAG_SHIFT    (3U)
#define AI_DIG_PLL_STATUS_S1_UNDERFLOW_FLAG(x)       ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_STATUS_S1_UNDERFLOW_FLAG_MASK) >> AI_DIG_PLL_STATUS_S1_UNDERFLOW_FLAG_SHIFT))

#define AI_DIG_PLL_STATUS_COUNT_SUM_LSB_MASK     (0x70U)
#define AI_DIG_PLL_STATUS_COUNT_SUM_LSB_SHIFT    (4U)
#define AI_DIG_PLL_STATUS_COUNT_SUM_LSB(x)       ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_STATUS_COUNT_SUM_LSB_MASK) >> AI_DIG_PLL_STATUS_COUNT_SUM_LSB_SHIFT))
#define AI_DIG_PLL_STATUS_FC_DS_MASK     (0x7F00U)
#define AI_DIG_PLL_STATUS_FC_DS_SHIFT    (8U)
#define AI_DIG_PLL_STATUS_FC_DS(x)       ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_STATUS_FC_DS_MASK) >> AI_DIG_PLL_STATUS_FC_DS_SHIFT))
#define AI_DIG_PLL_STATUS_FC_UFINE_MASK  (0x1FF0000U)
#define AI_DIG_PLL_STATUS_FC_UFINE_SHIFT (16U)
#define AI_DIG_PLL_STATUS_FC_UFINE(x)    ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_STATUS_FC_UFINE_MASK) >> AI_DIG_PLL_STATUS_FC_UFINE_SHIFT))
#define AI_DIG_PLL_STATUS_COUNT_SUM_MSB_MASK  (0xFE000000U)
#define AI_DIG_PLL_STATUS_COUNT_SUM_MSB_SHIFT (25U)
#define AI_DIG_PLL_STATUS_COUNT_SUM_MSB(x)    ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_STATUS_COUNT_SUM_MSB_MASK) >> AI_DIG_PLL_STATUS_COUNT_SUM_MSB_SHIFT))
#define AI_DIG_PLL_SPARE_SPARE_FIELD_MASK  (0xFFFFFFFFU)
#define AI_DIG_PLL_SPARE_SPARE_FIELD_SHIFT (0U)
#define AI_DIG_PLL_SPARE_SPARE_FIELD(x)    ((uint32_t)((((uint32_t)(x)) & AI_DIG_PLL_SPARE_SPARE_FIELD_MASK) >> AI_DIG_PLL_SPARE_SPARE_FIELD_SHIFT))

#define AI_HP_PLL_CTRL0_DIV_SELECT_MASK (0xFFU)
#define AI_HP_PLL_CTRL0_DIV_SELECT_SHIFT (0U)
#define AI_HP_PLL_CTRL0_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_DIV_SELECT_SHIFT)) & AI_HP_PLL_CTRL0_DIV_SELECT_MASK)
#define AI_HP_PLL_CTRL0_HALF_LF_R_MASK (0x100U)
#define AI_HP_PLL_CTRL0_HALF_LF_R_SHIFT (8U)
#define AI_HP_PLL_CTRL0_HALF_LF_R(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_HALF_LF_R_SHIFT)) & AI_HP_PLL_CTRL0_HALF_LF_R_MASK)
#define AI_HP_PLL_CTRL0_DOUBLE_LF_R_MASK (0x200U)
#define AI_HP_PLL_CTRL0_DOUBLE_LF_R_SHIFT (9U)
#define AI_HP_PLL_CTRL0_DOUBLE_LF_R(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_DOUBLE_LF_R_SHIFT)) & AI_HP_PLL_CTRL0_DOUBLE_LF_R_MASK)
#define AI_HP_PLL_CTRL0_HALF_CP_MASK (0x400U)
#define AI_HP_PLL_CTRL0_HALF_CP_SHIFT (10U)
#define AI_HP_PLL_CTRL0_HALF_CP(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_HALF_CP_SHIFT)) & AI_HP_PLL_CTRL0_HALF_CP_MASK)
#define AI_HP_PLL_CTRL0_DOUBLE_CP_MASK (0x800U)
#define AI_HP_PLL_CTRL0_DOUBLE_CP_SHIFT (11U)
#define AI_HP_PLL_CTRL0_DOUBLE_CP(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_DOUBLE_CP_SHIFT)) & AI_HP_PLL_CTRL0_DOUBLE_CP_MASK)
#define AI_HP_PLL_CTRL0_HOLD_RING_OFF_MASK (0x1000U)
#define AI_HP_PLL_CTRL0_HOLD_RING_OFF_SHIFT (12U)
#define AI_HP_PLL_CTRL0_HOLD_RING_OFF(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_HOLD_RING_OFF_SHIFT)) & AI_HP_PLL_CTRL0_HOLD_RING_OFF_MASK)
#define AI_HP_PLL_CTRL0_PLL_POWERUP_MASK (0x2000U)
#define AI_HP_PLL_CTRL0_PLL_POWERUP_SHIFT (13U)
#define AI_HP_PLL_CTRL0_PLL_POWERUP(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_PLL_POWERUP_SHIFT)) & AI_HP_PLL_CTRL0_PLL_POWERUP_MASK)
#define AI_HP_PLL_CTRL0_REF_PCIE_CLK_EN_MASK (0x4000U)
#define AI_HP_PLL_CTRL0_REF_PCIE_CLK_EN_SHIFT (14U)
#define AI_HP_PLL_CTRL0_REF_PCIE_CLK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_REF_PCIE_CLK_EN_SHIFT)) & AI_HP_PLL_CTRL0_REF_PCIE_CLK_EN_MASK)
#define AI_HP_PLL_CTRL0_CLK_BYPASS_MASK (0x8000U)
#define AI_HP_PLL_CTRL0_CLK_BYPASS_SHIFT (15U)
#define AI_HP_PLL_CTRL0_CLK_BYPASS(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_CLK_BYPASS_SHIFT)) & AI_HP_PLL_CTRL0_CLK_BYPASS_MASK)
#define AI_HP_PLL_CTRL0_BIAS_PWRUP_MASK (0x10000U)
#define AI_HP_PLL_CTRL0_BIAS_PWRUP_SHIFT (16U)
#define AI_HP_PLL_CTRL0_BIAS_PWRUP(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_BIAS_PWRUP_SHIFT)) & AI_HP_PLL_CTRL0_BIAS_PWRUP_MASK)
#define AI_HP_PLL_CTRL0_CLK_DCK_DIV4_EN_MASK (0x20000U)
#define AI_HP_PLL_CTRL0_CLK_DCK_DIV4_EN_SHIFT (17U)
#define AI_HP_PLL_CTRL0_CLK_DCK_DIV4_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_CLK_DCK_DIV4_EN_SHIFT)) & AI_HP_PLL_CTRL0_CLK_DCK_DIV4_EN_MASK)
#define AI_HP_PLL_CTRL0_CLK_DCK_DIV2_EN_MASK (0x40000U)
#define AI_HP_PLL_CTRL0_CLK_DCK_DIV2_EN_SHIFT (18U)
#define AI_HP_PLL_CTRL0_CLK_DCK_DIV2_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_CLK_DCK_DIV2_EN_SHIFT)) & AI_HP_PLL_CTRL0_CLK_DCK_DIV2_EN_MASK)
#define AI_HP_PLL_CTRL0_CLK_DCK_EN_MASK (0x80000U)
#define AI_HP_PLL_CTRL0_CLK_DCK_EN_SHIFT (19U)
#define AI_HP_PLL_CTRL0_CLK_DCK_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_CLK_DCK_EN_SHIFT)) & AI_HP_PLL_CTRL0_CLK_DCK_EN_MASK)
#define AI_HP_PLL_CTRL0_REGULATOR_LP_EN_MASK (0x100000U)
#define AI_HP_PLL_CTRL0_REGULATOR_LP_EN_SHIFT (20U)
#define AI_HP_PLL_CTRL0_REGULATOR_LP_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_REGULATOR_LP_EN_SHIFT)) & AI_HP_PLL_CTRL0_REGULATOR_LP_EN_MASK)
#define AI_HP_PLL_CTRL0_REGULATOR_EN_MASK (0x200000U)
#define AI_HP_PLL_CTRL0_REGULATOR_EN_SHIFT (21U)
#define AI_HP_PLL_CTRL0_REGULATOR_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_REGULATOR_EN_SHIFT)) & AI_HP_PLL_CTRL0_REGULATOR_EN_MASK)
#define AI_HP_PLL_CTRL0_REGULATOR_VOLT_TRIM_MASK (0xC00000U)
#define AI_HP_PLL_CTRL0_REGULATOR_VOLT_TRIM_SHIFT (22U)
#define AI_HP_PLL_CTRL0_REGULATOR_VOLT_TRIM(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_REGULATOR_VOLT_TRIM_SHIFT)) & AI_HP_PLL_CTRL0_REGULATOR_VOLT_TRIM_MASK)
#define AI_HP_PLL_CTRL0_REGULATOR_TST_EN_MASK (0x1000000U)
#define AI_HP_PLL_CTRL0_REGULATOR_TST_EN_SHIFT (24U)
#define AI_HP_PLL_CTRL0_REGULATOR_TST_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_REGULATOR_TST_EN_SHIFT)) & AI_HP_PLL_CTRL0_REGULATOR_TST_EN_MASK)
#define AI_HP_PLL_CTRL0_SEL_LVDS_DIV_MASK (0x2000000U)
#define AI_HP_PLL_CTRL0_SEL_LVDS_DIV_SHIFT (25U)
#define AI_HP_PLL_CTRL0_SEL_LVDS_DIV(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_SEL_LVDS_DIV_SHIFT)) & AI_HP_PLL_CTRL0_SEL_LVDS_DIV_MASK)
#define AI_HP_PLL_CTRL0_TESTMODE_MASK (0x4000000U)
#define AI_HP_PLL_CTRL0_TESTMODE_SHIFT (26U)
#define AI_HP_PLL_CTRL0_TESTMODE(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_TESTMODE_SHIFT)) & AI_HP_PLL_CTRL0_TESTMODE_MASK)
#define AI_HP_PLL_CTRL0_SEL_CLK_DIV_1P5_MASK (0x8000000U)
#define AI_HP_PLL_CTRL0_SEL_CLK_DIV_1P5_SHIFT (27U)
#define AI_HP_PLL_CTRL0_SEL_CLK_DIV_1P5(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_SEL_CLK_DIV_1P5_SHIFT)) & AI_HP_PLL_CTRL0_SEL_CLK_DIV_1P5_MASK)
#define AI_HP_PLL_CTRL0_CLK_DIV_1P5_EN_MASK (0x10000000U)
#define AI_HP_PLL_CTRL0_CLK_DIV_1P5_EN_SHIFT (28U)
#define AI_HP_PLL_CTRL0_CLK_DIV_1P5_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_CLK_DIV_1P5_EN_SHIFT)) & AI_HP_PLL_CTRL0_CLK_DIV_1P5_EN_MASK)
#define AI_HP_PLL_CTRL0_CLK_LVDS_EN_MASK (0x20000000U)
#define AI_HP_PLL_CTRL0_CLK_LVDS_EN_SHIFT (29U)
#define AI_HP_PLL_CTRL0_CLK_LVDS_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_CLK_LVDS_EN_SHIFT)) & AI_HP_PLL_CTRL0_CLK_LVDS_EN_MASK)
#define AI_HP_PLL_CTRL0_CLK_ISOLATION_B_MASK (0x40000000U)
#define AI_HP_PLL_CTRL0_CLK_ISOLATION_B_SHIFT (30U)
#define AI_HP_PLL_CTRL0_CLK_ISOLATION_B(x) (((uint32_t)(((uint32_t)(x)) << AI_HP_PLL_CTRL0_CLK_ISOLATION_B_SHIFT)) & AI_HP_PLL_CTRL0_CLK_ISOLATION_B_MASK)

#define AI_OSC24M_CTRLOSC_EN_OSC_LV_MASK (0x1U)
#define AI_OSC24M_CTRLOSC_EN_OSC_LV_SHIFT (0U)
#define AI_OSC24M_CTRLOSC_EN_OSC_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_EN_OSC_LV_SHIFT)) & AI_OSC24M_CTRLOSC_EN_OSC_LV_MASK)
#define AI_OSC24M_CTRLOSC_BYPASS_REGH_LV_MASK (0x2U)
#define AI_OSC24M_CTRLOSC_BYPASS_REGH_LV_SHIFT (1U)
#define AI_OSC24M_CTRLOSC_BYPASS_REGH_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_BYPASS_REGH_LV_SHIFT)) & AI_OSC24M_CTRLOSC_BYPASS_REGH_LV_MASK)
#define AI_OSC24M_CTRLOSC_BYPASS_REGL_LV_MASK (0x4U)
#define AI_OSC24M_CTRLOSC_BYPASS_REGL_LV_SHIFT (2U)
#define AI_OSC24M_CTRLOSC_BYPASS_REGL_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_BYPASS_REGL_LV_SHIFT)) & AI_OSC24M_CTRLOSC_BYPASS_REGL_LV_MASK)
#define AI_OSC24M_CTRLOSC_EN_CLK_EXT_LV_MASK (0x8U)
#define AI_OSC24M_CTRLOSC_EN_CLK_EXT_LV_SHIFT (3U)
#define AI_OSC24M_CTRLOSC_EN_CLK_EXT_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_EN_CLK_EXT_LV_SHIFT)) & AI_OSC24M_CTRLOSC_EN_CLK_EXT_LV_MASK)
#define AI_OSC24M_CTRLOSC_TUNE_REGH_LV_MASK (0x70U)
#define AI_OSC24M_CTRLOSC_TUNE_REGH_LV_SHIFT (4U)
#define AI_OSC24M_CTRLOSC_TUNE_REGH_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_TUNE_REGH_LV_SHIFT)) & AI_OSC24M_CTRLOSC_TUNE_REGH_LV_MASK)
#define AI_OSC24M_CTRLOSC_TUNE_REGL_LV_MASK (0x380U)
#define AI_OSC24M_CTRLOSC_TUNE_REGL_LV_SHIFT (7U)
#define AI_OSC24M_CTRLOSC_TUNE_REGL_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_TUNE_REGL_LV_SHIFT)) & AI_OSC24M_CTRLOSC_TUNE_REGL_LV_MASK)
#define AI_OSC24M_CTRLOSC_IREF_TUNE_LV_MASK (0xC00U)
#define AI_OSC24M_CTRLOSC_IREF_TUNE_LV_SHIFT (10U)
#define AI_OSC24M_CTRLOSC_IREF_TUNE_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_IREF_TUNE_LV_SHIFT)) & AI_OSC24M_CTRLOSC_IREF_TUNE_LV_MASK)
#define AI_OSC24M_CTRLOSC_CL_TUNE_LV_MASK (0xF000U)
#define AI_OSC24M_CTRLOSC_CL_TUNE_LV_SHIFT (12U)
#define AI_OSC24M_CTRLOSC_CL_TUNE_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_CL_TUNE_LV_SHIFT)) & AI_OSC24M_CTRLOSC_CL_TUNE_LV_MASK)
#define AI_OSC24M_CTRLOSC_ITAIL_PKDET_LV_MASK (0x30000U)
#define AI_OSC24M_CTRLOSC_ITAIL_PKDET_LV_SHIFT (16U)
#define AI_OSC24M_CTRLOSC_ITAIL_PKDET_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_ITAIL_PKDET_LV_SHIFT)) & AI_OSC24M_CTRLOSC_ITAIL_PKDET_LV_MASK)
#define AI_OSC24M_CTRLOSC_VTEST_SEL_LV_MASK (0x1C0000U)
#define AI_OSC24M_CTRLOSC_VTEST_SEL_LV_SHIFT (18U)
#define AI_OSC24M_CTRLOSC_VTEST_SEL_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_VTEST_SEL_LV_SHIFT)) & AI_OSC24M_CTRLOSC_VTEST_SEL_LV_MASK)
#define AI_OSC24M_CTRLOSC_TEST_ENABLE_LV_MASK (0x200000U)
#define AI_OSC24M_CTRLOSC_TEST_ENABLE_LV_SHIFT (21U)
#define AI_OSC24M_CTRLOSC_TEST_ENABLE_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_TEST_ENABLE_LV_SHIFT)) & AI_OSC24M_CTRLOSC_TEST_ENABLE_LV_MASK)
#define AI_OSC24M_CTRLOSC_REGL_STANDALONE_LV_MASK (0x400000U)
#define AI_OSC24M_CTRLOSC_REGL_STANDALONE_LV_SHIFT (22U)
#define AI_OSC24M_CTRLOSC_REGL_STANDALONE_LV(x) (((uint32_t)(((uint32_t)(x)) << AI_OSC24M_CTRLOSC_REGL_STANDALONE_LV_SHIFT)) & AI_OSC24M_CTRLOSC_REGL_STANDALONE_LV_MASK)
#define AI_OSC24M_STATOSC_CLK_OKAY_LV_MASK (0x1U)
#define AI_OSC24M_STATOSC_CLK_OKAY_LV_SHIFT (0U)
#define AI_OSC24M_STATOSC_CLK_OKAY_LV(x) ((uint32_t)((((uint32_t)(x)) & AI_OSC24M_STATOSC_CLK_OKAY_LV_MASK) >> AI_OSC24M_STATOSC_CLK_OKAY_LV_SHIFT))
#define AI_RC200OSC_CTRL0_REF_CLK_DIV_MASK (0x3F000000U)
#define AI_RC200OSC_CTRL0_REF_CLK_DIV_SHIFT (24U)
#define AI_RC200OSC_CTRL0_REF_CLK_DIV(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL0_REF_CLK_DIV_SHIFT)) & AI_RC200OSC_CTRL0_REF_CLK_DIV_MASK)
#define AI_RC200OSC_CTRL1_HYST_MINUS_MASK (0xFU)
#define AI_RC200OSC_CTRL1_HYST_MINUS_SHIFT (0U)
#define AI_RC200OSC_CTRL1_HYST_MINUS(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL1_HYST_MINUS_SHIFT)) & AI_RC200OSC_CTRL1_HYST_MINUS_MASK)
#define AI_RC200OSC_CTRL1_HYST_PLUS_MASK (0xF00U)
#define AI_RC200OSC_CTRL1_HYST_PLUS_SHIFT (8U)
#define AI_RC200OSC_CTRL1_HYST_PLUS(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL1_HYST_PLUS_SHIFT)) & AI_RC200OSC_CTRL1_HYST_PLUS_MASK)
#define AI_RC200OSC_CTRL1_TARGET_COUNT_MASK (0xFFFF0000U)
#define AI_RC200OSC_CTRL1_TARGET_COUNT_SHIFT (16U)
#define AI_RC200OSC_CTRL1_TARGET_COUNT(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL1_TARGET_COUNT_SHIFT)) & AI_RC200OSC_CTRL1_TARGET_COUNT_MASK)
#define AI_RC200OSC_CTRL2_TUNE_INV_MASK (0x100U)
#define AI_RC200OSC_CTRL2_TUNE_INV_SHIFT (8U)
#define AI_RC200OSC_CTRL2_TUNE_INV(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL2_TUNE_INV_SHIFT)) & AI_RC200OSC_CTRL2_TUNE_INV_MASK)
#define AI_RC200OSC_CTRL2_TUNE_BYP_MASK (0x400U)
#define AI_RC200OSC_CTRL2_TUNE_BYP_SHIFT (10U)
#define AI_RC200OSC_CTRL2_TUNE_BYP(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL2_TUNE_BYP_SHIFT)) & AI_RC200OSC_CTRL2_TUNE_BYP_MASK)
#define AI_RC200OSC_CTRL2_TUNE_EN_MASK (0x1000U)
#define AI_RC200OSC_CTRL2_TUNE_EN_SHIFT (12U)
#define AI_RC200OSC_CTRL2_TUNE_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL2_TUNE_EN_SHIFT)) & AI_RC200OSC_CTRL2_TUNE_EN_MASK)
#define AI_RC200OSC_CTRL2_TUNE_START_MASK (0x4000U)
#define AI_RC200OSC_CTRL2_TUNE_START_SHIFT (14U)
#define AI_RC200OSC_CTRL2_TUNE_START(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL2_TUNE_START_SHIFT)) & AI_RC200OSC_CTRL2_TUNE_START_MASK)
#define AI_RC200OSC_CTRL2_OSC_TUNE_VAL_MASK (0xFF000000U)
#define AI_RC200OSC_CTRL2_OSC_TUNE_VAL_SHIFT (24U)
#define AI_RC200OSC_CTRL2_OSC_TUNE_VAL(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL2_OSC_TUNE_VAL_SHIFT)) & AI_RC200OSC_CTRL2_OSC_TUNE_VAL_MASK)
#define AI_RC200OSC_CTRL3_CLR_ERR_MASK (0x1U)
#define AI_RC200OSC_CTRL3_CLR_ERR_SHIFT (0U)
#define AI_RC200OSC_CTRL3_CLR_ERR(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL3_CLR_ERR_SHIFT)) & AI_RC200OSC_CTRL3_CLR_ERR_MASK)
#define AI_RC200OSC_CTRL3_EN_1M_CLK_MASK (0x100U)
#define AI_RC200OSC_CTRL3_EN_1M_CLK_SHIFT (8U)
#define AI_RC200OSC_CTRL3_EN_1M_CLK(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL3_EN_1M_CLK_SHIFT)) & AI_RC200OSC_CTRL3_EN_1M_CLK_MASK)
#define AI_RC200OSC_CTRL3_MUX_1M_CLK_MASK (0x400U)
#define AI_RC200OSC_CTRL3_MUX_1M_CLK_SHIFT (10U)
#define AI_RC200OSC_CTRL3_MUX_1M_CLK(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL3_MUX_1M_CLK_SHIFT)) & AI_RC200OSC_CTRL3_MUX_1M_CLK_MASK)
#define AI_RC200OSC_CTRL3_COUNT_1M_CLK_MASK (0xFFFF0000U)
#define AI_RC200OSC_CTRL3_COUNT_1M_CLK_SHIFT (16U)
#define AI_RC200OSC_CTRL3_COUNT_1M_CLK(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL3_COUNT_1M_CLK_SHIFT)) & AI_RC200OSC_CTRL3_COUNT_1M_CLK_MASK)
#define AI_RC200OSC_CTRL4_REF_MUX_CTRL_MASK (0x30000U)
#define AI_RC200OSC_CTRL4_REF_MUX_CTRL_SHIFT (16U)
#define AI_RC200OSC_CTRL4_REF_MUX_CTRL(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL4_REF_MUX_CTRL_SHIFT)) & AI_RC200OSC_CTRL4_REF_MUX_CTRL_MASK)
#define AI_RC200OSC_CTRL4_LVDS_MUX_CTRL_MASK (0x300000U)
#define AI_RC200OSC_CTRL4_LVDS_MUX_CTRL_SHIFT (20U)
#define AI_RC200OSC_CTRL4_LVDS_MUX_CTRL(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL4_LVDS_MUX_CTRL_SHIFT)) & AI_RC200OSC_CTRL4_LVDS_MUX_CTRL_MASK)
#define AI_RC200OSC_CTRL4_LVDS_OUT_EN_MASK (0x1000000U)
#define AI_RC200OSC_CTRL4_LVDS_OUT_EN_SHIFT (24U)
#define AI_RC200OSC_CTRL4_LVDS_OUT_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL4_LVDS_OUT_EN_SHIFT)) & AI_RC200OSC_CTRL4_LVDS_OUT_EN_MASK)
#define AI_RC200OSC_CTRL4_PWD_MASK (0x20000000U)
#define AI_RC200OSC_CTRL4_PWD_SHIFT (29U)
#define AI_RC200OSC_CTRL4_PWD(x)  (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL4_PWD_SHIFT)) & AI_RC200OSC_CTRL4_PWD_MASK)
#define AI_RC200OSC_CTRL4_OSC_EN_MASK (0x80000000U)
#define AI_RC200OSC_CTRL4_OSC_EN_SHIFT (31U)
#define AI_RC200OSC_CTRL4_OSC_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_RC200OSC_CTRL4_OSC_EN_SHIFT)) & AI_RC200OSC_CTRL4_OSC_EN_MASK)
#define AI_RC200OSC_STAT0_CLK1M_ERR_MASK (0x1U)
#define AI_RC200OSC_STAT0_CLK1M_ERR_SHIFT (0U)
#define AI_RC200OSC_STAT0_CLK1M_ERR(x) ((uint32_t)((((uint32_t)(x)) & AI_RC200OSC_STAT0_CLK1M_ERR_MASK) >> AI_RC200OSC_STAT0_CLK1M_ERR_SHIFT))
#define AI_RC200OSC_STAT1_CURR_COUNT_VAL_MASK (0xFFFF0000U)
#define AI_RC200OSC_STAT1_CURR_COUNT_VAL_SHIFT (16U)
#define AI_RC200OSC_STAT1_CURR_COUNT_VAL(x) ((uint32_t)((((uint32_t)(x)) & AI_RC200OSC_STAT1_CURR_COUNT_VAL_MASK) >> AI_RC200OSC_STAT1_CURR_COUNT_VAL_SHIFT))
#define AI_RC200OSC_STAT2_CURR_OSC_TUNE_VAL_MASK (0xFF000000U)
#define AI_RC200OSC_STAT2_CURR_OSC_TUNE_VAL_SHIFT (24U)
#define AI_RC200OSC_STAT2_CURR_OSC_TUNE_VAL(x) ((uint32_t)((((uint32_t)(x)) & AI_RC200OSC_STAT2_CURR_OSC_TUNE_VAL_MASK) >> AI_RC200OSC_STAT2_CURR_OSC_TUNE_VAL_SHIFT))

#define AI_VDROP_PROCMON_CTRL0_DLY_RUN_MASK   (0x1U)
#define AI_VDROP_PROCMON_CTRL0_DLY_RUN_SHIFT  (0U)
#define AI_VDROP_PROCMON_CTRL0_DLY_RUN(x)     (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_CTRL0_DLY_RUN_SHIFT)) & AI_VDROP_PROCMON_CTRL0_DLY_RUN_MASK)
#define AI_VDROP_PROCMON_CTRL0_DLY_RELOCK_MASK (0x2U)
#define AI_VDROP_PROCMON_CTRL0_DLY_RELOCK_SHIFT (1U)
#define AI_VDROP_PROCMON_CTRL0_DLY_RELOCK(x)  (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_CTRL0_DLY_RELOCK_SHIFT)) & AI_VDROP_PROCMON_CTRL0_DLY_RELOCK_MASK)
#define AI_VDROP_PROCMON_CTRL0_DLY_1P_EN_MASK (0x4U)
#define AI_VDROP_PROCMON_CTRL0_DLY_1P_EN_SHIFT (2U)
#define AI_VDROP_PROCMON_CTRL0_DLY_1P_EN(x)   (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_CTRL0_DLY_1P_EN_SHIFT)) & AI_VDROP_PROCMON_CTRL0_DLY_1P_EN_MASK)
#define AI_VDROP_PROCMON_CTRL0_PLL_CNT_EN_MASK (0x8U)
#define AI_VDROP_PROCMON_CTRL0_PLL_CNT_EN_SHIFT (3U)
#define AI_VDROP_PROCMON_CTRL0_PLL_CNT_EN(x)  (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_CTRL0_PLL_CNT_EN_SHIFT)) & AI_VDROP_PROCMON_CTRL0_PLL_CNT_EN_MASK)
#define AI_VDROP_PROCMON_CTRL0_CLKGATE_CTRL_MASK (0x30U)
#define AI_VDROP_PROCMON_CTRL0_CLKGATE_CTRL_SHIFT (4U)
#define AI_VDROP_PROCMON_CTRL0_CLKGATE_CTRL(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_CTRL0_CLKGATE_CTRL_SHIFT)) & AI_VDROP_PROCMON_CTRL0_CLKGATE_CTRL_MASK)
#define AI_VDROP_PROCMON_CTRL0_ADLY_SETTLE_CNT_MASK (0x3C0U)
#define AI_VDROP_PROCMON_CTRL0_ADLY_SETTLE_CNT_SHIFT (6U)
#define AI_VDROP_PROCMON_CTRL0_ADLY_SETTLE_CNT(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_CTRL0_ADLY_SETTLE_CNT_SHIFT)) & AI_VDROP_PROCMON_CTRL0_ADLY_SETTLE_CNT_MASK)
#define AI_VDROP_PROCMON_CTRL0_TST_CLKGATE_CTRL_MASK (0x400U)
#define AI_VDROP_PROCMON_CTRL0_TST_CLKGATE_CTRL_SHIFT (10U)
#define AI_VDROP_PROCMON_CTRL0_TST_CLKGATE_CTRL(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_CTRL0_TST_CLKGATE_CTRL_SHIFT)) & AI_VDROP_PROCMON_CTRL0_TST_CLKGATE_CTRL_MASK)
#define AI_VDROP_PROCMON_CTRL0_STATUS_SEL_MASK (0xF0000U)
#define AI_VDROP_PROCMON_CTRL0_STATUS_SEL_SHIFT (16U)
#define AI_VDROP_PROCMON_CTRL0_STATUS_SEL(x)  (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_CTRL0_STATUS_SEL_SHIFT)) & AI_VDROP_PROCMON_CTRL0_STATUS_SEL_MASK)
#define AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_XCK_NXT_UPD_SVAL_MASK (0xFFU)
#define AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_XCK_NXT_UPD_SVAL_SHIFT (0U)
#define AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_XCK_NXT_UPD_SVAL(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_XCK_NXT_UPD_SVAL_SHIFT)) & AI_VDROP_PROCMON_XTAL24M_TIMER_CTRL_XCK_NXT_UPD_SVAL_MASK)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_TAP_MASK (0x3FU)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_TAP_SHIFT (0U)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_TAP(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_TAP_SHIFT)) & AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_TAP_MASK)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_OVRD_EN_MASK (0x80000000U)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_OVRD_EN_SHIFT (31U)
#define AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_OVRD_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_OVRD_EN_SHIFT)) & AI_VDROP_PROCMON_ADLY_CHAIN_CTRL_ADLY_ENC_OVRD_EN_MASK)
#define AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_FDLY_UPDC_ADLY_INC_WTMK_MASK (0x7FFFU)
#define AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_FDLY_UPDC_ADLY_INC_WTMK_SHIFT (0U)
#define AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_FDLY_UPDC_ADLY_INC_WTMK(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_FDLY_UPDC_ADLY_INC_WTMK_SHIFT)) & AI_VDROP_PROCMON_UPDATE_INC_WATERMARK_FDLY_UPDC_ADLY_INC_WTMK_MASK)
#define AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_FDLY_UPDC_ADLY_DEC_WTMK_MASK (0x7FFFU)
#define AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_FDLY_UPDC_ADLY_DEC_WTMK_SHIFT (0U)
#define AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_FDLY_UPDC_ADLY_DEC_WTMK(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_FDLY_UPDC_ADLY_DEC_WTMK_SHIFT)) & AI_VDROP_PROCMON_UPDATE_DEC_WATERMARK_FDLY_UPDC_ADLY_DEC_WTMK_MASK)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_WTMK_MASK (0x1FU)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_WTMK_SHIFT (0U)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_WTMK(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_WTMK_SHIFT)) & AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_WTMK_MASK)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_LOCK_BIT_MASK (0x1F0000U)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_LOCK_BIT_SHIFT (16U)
#define AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_LOCK_BIT(x) (((uint32_t)(((uint32_t)(x)) << AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_LOCK_BIT_SHIFT)) & AI_VDROP_PROCMON_FDLY_TAP_CTRL_FDLY_TAP_LOCK_BIT_MASK)
#define AI_VDROP_PROCMON_DEBUG_STATUS_DEBUG_STATUS_MASK (0xFFFFFFFFU)
#define AI_VDROP_PROCMON_DEBUG_STATUS_DEBUG_STATUS_SHIFT (0U)
#define AI_VDROP_PROCMON_DEBUG_STATUS_DEBUG_STATUS(x) ((uint32_t)((((uint32_t)(x)) & AI_VDROP_PROCMON_DEBUG_STATUS_DEBUG_STATUS_MASK) >> AI_VDROP_PROCMON_DEBUG_STATUS_DEBUG_STATUS_SHIFT))

#define AI_TEMP_SENSE_CTRL0_SLOPE_CAL_MASK              (0x3FU)
#define AI_TEMP_SENSE_CTRL0_SLOPE_CAL_SHIFT             (0U)
#define AI_TEMP_SENSE_CTRL0_SLOPE_CAL(x)                (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL0_SLOPE_CAL_SHIFT)) & AI_TEMP_SENSE_CTRL0_SLOPE_CAL_MASK)
#define AI_TEMP_SENSE_CTRL0_V_SEL_MASK                  (0x300U)
#define AI_TEMP_SENSE_CTRL0_V_SEL_SHIFT                 (8U)
#define AI_TEMP_SENSE_CTRL0_V_SEL(x)                    (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL0_V_SEL_SHIFT)) & AI_TEMP_SENSE_CTRL0_V_SEL_MASK)
#define AI_TEMP_SENSE_CTRL0_IBIAS_TRIM_MASK             (0xF000U)
#define AI_TEMP_SENSE_CTRL0_IBIAS_TRIM_SHIFT            (12U)
#define AI_TEMP_SENSE_CTRL0_IBIAS_TRIM(x)               (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL0_IBIAS_TRIM_SHIFT)) & AI_TEMP_SENSE_CTRL0_IBIAS_TRIM_MASK)
#define AI_TEMP_SENSE_CTRL1_FREQ_MASK                   (0xFFFFU)
#define AI_TEMP_SENSE_CTRL1_FREQ_SHIFT                  (0U)
#define AI_TEMP_SENSE_CTRL1_FREQ(x)                     (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL1_FREQ_SHIFT)) & AI_TEMP_SENSE_CTRL1_FREQ_MASK)
#define AI_TEMP_SENSE_CTRL1_FINISH_IE_MASK              (0x10000U)
#define AI_TEMP_SENSE_CTRL1_FINISH_IE_SHIFT             (16U)
#define AI_TEMP_SENSE_CTRL1_FINISH_IE(x)                (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL1_FINISH_IE_SHIFT)) & AI_TEMP_SENSE_CTRL1_FINISH_IE_MASK)
#define AI_TEMP_SENSE_CTRL1_LOW_TEMP_IE_MASK            (0x20000U)
#define AI_TEMP_SENSE_CTRL1_LOW_TEMP_IE_SHIFT           (17U)
#define AI_TEMP_SENSE_CTRL1_LOW_TEMP_IE(x)              (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL1_LOW_TEMP_IE_SHIFT)) & AI_TEMP_SENSE_CTRL1_LOW_TEMP_IE_MASK)
#define AI_TEMP_SENSE_CTRL1_HIGH_TEMP_IE_MASK           (0x40000U)
#define AI_TEMP_SENSE_CTRL1_HIGH_TEMP_IE_SHIFT          (18U)
#define AI_TEMP_SENSE_CTRL1_HIGH_TEMP_IE(x)             (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL1_HIGH_TEMP_IE_SHIFT)) & AI_TEMP_SENSE_CTRL1_HIGH_TEMP_IE_MASK)
#define AI_TEMP_SENSE_CTRL1_PANIC_TEMP_IE_MASK          (0x80000U)
#define AI_TEMP_SENSE_CTRL1_PANIC_TEMP_IE_SHIFT         (19U)
#define AI_TEMP_SENSE_CTRL1_PANIC_TEMP_IE(x)            (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL1_PANIC_TEMP_IE_SHIFT)) & AI_TEMP_SENSE_CTRL1_PANIC_TEMP_IE_MASK)
#define AI_TEMP_SENSE_CTRL1_START_MASK                  (0x400000U)
#define AI_TEMP_SENSE_CTRL1_START_SHIFT                 (22U)
#define AI_TEMP_SENSE_CTRL1_START(x)                    (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL1_START_SHIFT)) & AI_TEMP_SENSE_CTRL1_START_MASK)
#define AI_TEMP_SENSE_CTRL1_PWD_MASK                    (0x800000U)
#define AI_TEMP_SENSE_CTRL1_PWD_SHIFT                   (23U)
#define AI_TEMP_SENSE_CTRL1_PWD(x)                      (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL1_PWD_SHIFT)) & AI_TEMP_SENSE_CTRL1_PWD_MASK)
#define AI_TEMP_SENSE_CTRL1_FULL_PWD_MASK               (0x80000000U)
#define AI_TEMP_SENSE_CTRL1_FULL_PWD_SHIFT              (31U)
#define AI_TEMP_SENSE_CTRL1_FULL_PWD(x)                 (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_CTRL1_FULL_PWD_SHIFT)) & AI_TEMP_SENSE_CTRL1_FULL_PWD_MASK)
#define AI_TEMP_SENSE_RANGE0_LOW_TEMP_VAL_MASK          (0xFFFU)
#define AI_TEMP_SENSE_RANGE0_LOW_TEMP_VAL_SHIFT         (0U)
#define AI_TEMP_SENSE_RANGE0_LOW_TEMP_VAL(x)            (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_RANGE0_LOW_TEMP_VAL_SHIFT)) & AI_TEMP_SENSE_RANGE0_LOW_TEMP_VAL_MASK)
#define AI_TEMP_SENSE_RANGE0_HIGH_TEMP_VAL_MASK         (0xFFF0000U)
#define AI_TEMP_SENSE_RANGE0_HIGH_TEMP_VAL_SHIFT        (16U)
#define AI_TEMP_SENSE_RANGE0_HIGH_TEMP_VAL(x)           (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_RANGE0_HIGH_TEMP_VAL_SHIFT)) & AI_TEMP_SENSE_RANGE0_HIGH_TEMP_VAL_MASK)
#define AI_TEMP_SENSE_RANGE1_PANIC_TEMP_VAL_MASK        (0xFFFU)
#define AI_TEMP_SENSE_RANGE1_PANIC_TEMP_VAL_SHIFT       (0U)
#define AI_TEMP_SENSE_RANGE1_PANIC_TEMP_VAL(x)          (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_RANGE1_PANIC_TEMP_VAL_SHIFT)) & AI_TEMP_SENSE_RANGE1_PANIC_TEMP_VAL_MASK)
#define AI_TEMP_SENSE_STATUS0_TEMP_VAL_MASK             (0xFFFU)
#define AI_TEMP_SENSE_STATUS0_TEMP_VAL_SHIFT            (0U)
#define AI_TEMP_SENSE_STATUS0_TEMP_VAL(x)               ((uint32_t)((((uint32_t)(x)) & AI_TEMP_SENSE_STATUS0_TEMP_VAL_MASK) >> AI_TEMP_SENSE_STATUS0_TEMP_VAL_SHIFT))
#define AI_TEMP_SENSE_STATUS0_TEMP_VAL_W1C(x)           (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_STATUS0_TEMP_VAL_SHIFT)) & AI_TEMP_SENSE_STATUS0_TEMP_VAL_MASK)
#define AI_TEMP_SENSE_STATUS0_FINISH_MASK               (0x10000U)
#define AI_TEMP_SENSE_STATUS0_FINISH_SHIFT              (16U)
#define AI_TEMP_SENSE_STATUS0_FINISH(x)                 ((uint32_t)((((uint32_t)(x)) & AI_TEMP_SENSE_STATUS0_FINISH_MASK) >> AI_TEMP_SENSE_STATUS0_FINISH_SHIFT))
#define AI_TEMP_SENSE_STATUS0_FINISH_W1C(x)             (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_STATUS0_FINISH_SHIFT)) & AI_TEMP_SENSE_STATUS0_FINISH_MASK)
#define AI_TEMP_SENSE_STATUS0_LOW_TEMP_MASK             (0x20000U)
#define AI_TEMP_SENSE_STATUS0_LOW_TEMP_SHIFT            (17U)
#define AI_TEMP_SENSE_STATUS0_LOW_TEMP(x)               ((uint32_t)((((uint32_t)(x)) & AI_TEMP_SENSE_STATUS0_LOW_TEMP_MASK) >> AI_TEMP_SENSE_STATUS0_LOW_TEMP_SHIFT))
#define AI_TEMP_SENSE_STATUS0_LOW_TEMP_W1C(x)           (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_STATUS0_LOW_TEMP_SHIFT)) & AI_TEMP_SENSE_STATUS0_LOW_TEMP_MASK)
#define AI_TEMP_SENSE_STATUS0_HIGH_TEMP_MASK            (0x40000U)
#define AI_TEMP_SENSE_STATUS0_HIGH_TEMP_SHIFT           (18U)
#define AI_TEMP_SENSE_STATUS0_HIGH_TEMP(x)              ((uint32_t)((((uint32_t)(x)) & AI_TEMP_SENSE_STATUS0_HIGH_TEMP_MASK) >> AI_TEMP_SENSE_STATUS0_HIGH_TEMP_SHIFT))
#define AI_TEMP_SENSE_STATUS0_HIGH_TEMP_W1C(x)          (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_STATUS0_HIGH_TEMP_SHIFT)) & AI_TEMP_SENSE_STATUS0_HIGH_TEMP_MASK)
#define AI_TEMP_SENSE_STATUS0_PANIC_TEMP_MASK           (0x80000U)
#define AI_TEMP_SENSE_STATUS0_PANIC_TEMP_SHIFT          (19U)
#define AI_TEMP_SENSE_STATUS0_PANIC_TEMP(x)             ((uint32_t)((((uint32_t)(x)) & AI_TEMP_SENSE_STATUS0_PANIC_TEMP_MASK) >> AI_TEMP_SENSE_STATUS0_PANIC_TEMP_SHIFT))
#define AI_TEMP_SENSE_STATUS0_PANIC_TEMP_W1C(x)         (((uint32_t)(((uint32_t)(x)) << AI_TEMP_SENSE_STATUS0_PANIC_TEMP_SHIFT)) & AI_TEMP_SENSE_STATUS0_PANIC_TEMP_MASK)

#define AI_LVDS_TRANS_CTRL0_IPP_OBE_MASK (0x1U)
#define AI_LVDS_TRANS_CTRL0_IPP_OBE_SHIFT (0U)
#define AI_LVDS_TRANS_CTRL0_IPP_OBE(x) (((uint32_t)(((uint32_t)(x)) << AI_LVDS_TRANS_CTRL0_IPP_OBE_SHIFT)) & AI_LVDS_TRANS_CTRL0_IPP_OBE_MASK)
#define AI_LVDS_TRANS_CTRL0_IPP_IBE_MASK (0x2U)
#define AI_LVDS_TRANS_CTRL0_IPP_IBE_SHIFT (1U)
#define AI_LVDS_TRANS_CTRL0_IPP_IBE(x) (((uint32_t)(((uint32_t)(x)) << AI_LVDS_TRANS_CTRL0_IPP_IBE_SHIFT)) & AI_LVDS_TRANS_CTRL0_IPP_IBE_MASK)
#define AI_LVDS_TRANS_CTRL0_I_TRIM_MASK (0xCU)
#define AI_LVDS_TRANS_CTRL0_I_TRIM_SHIFT (2U)
#define AI_LVDS_TRANS_CTRL0_I_TRIM(x) (((uint32_t)(((uint32_t)(x)) << AI_LVDS_TRANS_CTRL0_I_TRIM_SHIFT)) & AI_LVDS_TRANS_CTRL0_I_TRIM_MASK)
#define AI_LVDS_TRANS_CTRL0_INPUT_SOURCE_MASK (0x30U)
#define AI_LVDS_TRANS_CTRL0_INPUT_SOURCE_SHIFT (4U)
#define AI_LVDS_TRANS_CTRL0_INPUT_SOURCE(x) (((uint32_t)(((uint32_t)(x)) << AI_LVDS_TRANS_CTRL0_INPUT_SOURCE_SHIFT)) & AI_LVDS_TRANS_CTRL0_INPUT_SOURCE_MASK)
#define AI_LVDS_TRANS_CTRL0_ANA_TEST_EN_MASK (0x40U)
#define AI_LVDS_TRANS_CTRL0_ANA_TEST_EN_SHIFT (6U)
#define AI_LVDS_TRANS_CTRL0_ANA_TEST_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_LVDS_TRANS_CTRL0_ANA_TEST_EN_SHIFT)) & AI_LVDS_TRANS_CTRL0_ANA_TEST_EN_MASK)
#define AI_LVDS_TRANS_CTRL0_DIV4_EN_MASK (0x80U)
#define AI_LVDS_TRANS_CTRL0_DIV4_EN_SHIFT (7U)
#define AI_LVDS_TRANS_CTRL0_DIV4_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_LVDS_TRANS_CTRL0_DIV4_EN_SHIFT)) & AI_LVDS_TRANS_CTRL0_DIV4_EN_MASK)

#define AI_NEG_CHARGE_PUMP_CTRL0_EN_NCP_MASK (0x1U)
#define AI_NEG_CHARGE_PUMP_CTRL0_EN_NCP_SHIFT (0U)
#define AI_NEG_CHARGE_PUMP_CTRL0_EN_NCP(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_EN_NCP_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_EN_NCP_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_TRIM_VNEG_MASK (0x3EU)
#define AI_NEG_CHARGE_PUMP_CTRL0_TRIM_VNEG_SHIFT (1U)
#define AI_NEG_CHARGE_PUMP_CTRL0_TRIM_VNEG(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_TRIM_VNEG_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_TRIM_VNEG_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_CLK_DIV_MASK (0x40U)
#define AI_NEG_CHARGE_PUMP_CTRL0_CLK_DIV_SHIFT (6U)
#define AI_NEG_CHARGE_PUMP_CTRL0_CLK_DIV(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_CLK_DIV_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_CLK_DIV_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_DIS_CP_MASK (0x380U)
#define AI_NEG_CHARGE_PUMP_CTRL0_DIS_CP_SHIFT (7U)
#define AI_NEG_CHARGE_PUMP_CTRL0_DIS_CP(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_DIS_CP_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_DIS_CP_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_MASK (0x400U)
#define AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_SHIFT (10U)
#define AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_SEL_MASK (0x800U)
#define AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_SEL_SHIFT (11U)
#define AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_SEL_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_OPEN_SW_SEL_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_B_MASK (0x1000U)
#define AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_B_SHIFT (12U)
#define AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_B(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_B_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_B_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_SEL_MASK (0x2000U)
#define AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_SEL_SHIFT (13U)
#define AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_SEL_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_RST_VNEG_OK_SEL_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_SKIP_MODE_MASK (0x4000U)
#define AI_NEG_CHARGE_PUMP_CTRL0_SKIP_MODE_SHIFT (14U)
#define AI_NEG_CHARGE_PUMP_CTRL0_SKIP_MODE(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_SKIP_MODE_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_SKIP_MODE_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_TEST_MODE_MASK (0x38000U)
#define AI_NEG_CHARGE_PUMP_CTRL0_TEST_MODE_SHIFT (15U)
#define AI_NEG_CHARGE_PUMP_CTRL0_TEST_MODE(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_TEST_MODE_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_TEST_MODE_MASK)
#define AI_NEG_CHARGE_PUMP_CTRL0_EXTRA_MASK (0x1C0000U)
#define AI_NEG_CHARGE_PUMP_CTRL0_EXTRA_SHIFT (18U)
#define AI_NEG_CHARGE_PUMP_CTRL0_EXTRA(x) (((uint32_t)(((uint32_t)(x)) << AI_NEG_CHARGE_PUMP_CTRL0_EXTRA_SHIFT)) & AI_NEG_CHARGE_PUMP_CTRL0_EXTRA_MASK)
#define AI_NEG_CHARGE_PUMP_STAT0_VNEG_OK_MASK (0x1U)
#define AI_NEG_CHARGE_PUMP_STAT0_VNEG_OK_SHIFT (0U)
#define AI_NEG_CHARGE_PUMP_STAT0_VNEG_OK(x) ((uint32_t)((((uint32_t)(x)) & AI_NEG_CHARGE_PUMP_STAT0_VNEG_OK_MASK) >> AI_NEG_CHARGE_PUMP_STAT0_VNEG_OK_SHIFT))
#define AI_NEG_CHARGE_PUMP_STAT0_SKIP_MASK (0x2U)
#define AI_NEG_CHARGE_PUMP_STAT0_SKIP_SHIFT (1U)
#define AI_NEG_CHARGE_PUMP_STAT0_SKIP(x) ((uint32_t)((((uint32_t)(x)) & AI_NEG_CHARGE_PUMP_STAT0_SKIP_MASK) >> AI_NEG_CHARGE_PUMP_STAT0_SKIP_SHIFT))
#define AI_NEG_CHARGE_PUMP_STAT0_SW_CLOSED_MASK (0x4U)
#define AI_NEG_CHARGE_PUMP_STAT0_SW_CLOSED_SHIFT (2U)
#define AI_NEG_CHARGE_PUMP_STAT0_SW_CLOSED(x) ((uint32_t)((((uint32_t)(x)) & AI_NEG_CHARGE_PUMP_STAT0_SW_CLOSED_MASK) >> AI_NEG_CHARGE_PUMP_STAT0_SW_CLOSED_SHIFT))
#define AI_NEG_CHARGE_PUMP_STAT0_SW_DISCHARGE_MASK (0x8U)
#define AI_NEG_CHARGE_PUMP_STAT0_SW_DISCHARGE_SHIFT (3U)
#define AI_NEG_CHARGE_PUMP_STAT0_SW_DISCHARGE(x) ((uint32_t)((((uint32_t)(x)) & AI_NEG_CHARGE_PUMP_STAT0_SW_DISCHARGE_MASK) >> AI_NEG_CHARGE_PUMP_STAT0_SW_DISCHARGE_SHIFT))
#define AI_NEG_CHARGE_PUMP_STAT0_SW_OPEN_MASK (0x10U)
#define AI_NEG_CHARGE_PUMP_STAT0_SW_OPEN_SHIFT (4U)
#define AI_NEG_CHARGE_PUMP_STAT0_SW_OPEN(x) ((uint32_t)((((uint32_t)(x)) & AI_NEG_CHARGE_PUMP_STAT0_SW_OPEN_MASK) >> AI_NEG_CHARGE_PUMP_STAT0_SW_OPEN_SHIFT))

#define AI_WELL_LEVEL_SOURCE_CTRL0_REF_V_CTRL_MASK (0xFFU)
#define AI_WELL_LEVEL_SOURCE_CTRL0_REF_V_CTRL_SHIFT (0U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_REF_V_CTRL(x) (((uint32_t)(((uint32_t)(x)) << AI_WELL_LEVEL_SOURCE_CTRL0_REF_V_CTRL_SHIFT)) & AI_WELL_LEVEL_SOURCE_CTRL0_REF_V_CTRL_MASK)
#define AI_WELL_LEVEL_SOURCE_CTRL0_V_FB_MASK   (0x700U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_V_FB_SHIFT  (8U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_V_FB(x)     (((uint32_t)(((uint32_t)(x)) << AI_WELL_LEVEL_SOURCE_CTRL0_V_FB_SHIFT)) & AI_WELL_LEVEL_SOURCE_CTRL0_V_FB_MASK)
#define AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_SEL_MASK (0xF800U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_SEL_SHIFT (11U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_SEL_SHIFT)) & AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_SEL_MASK)
#define AI_WELL_LEVEL_SOURCE_CTRL0_EN_REG_LINES_MASK (0x1F0000U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_EN_REG_LINES_SHIFT (16U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_EN_REG_LINES(x) (((uint32_t)(((uint32_t)(x)) << AI_WELL_LEVEL_SOURCE_CTRL0_EN_REG_LINES_SHIFT)) & AI_WELL_LEVEL_SOURCE_CTRL0_EN_REG_LINES_MASK)
#define AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_BLK_SEL_MASK (0xE00000U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_BLK_SEL_SHIFT (21U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_BLK_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_BLK_SEL_SHIFT)) & AI_WELL_LEVEL_SOURCE_CTRL0_TEST_MODE_BLK_SEL_MASK)
#define AI_WELL_LEVEL_SOURCE_CTRL0_EN_DLYD_REG_LINES_MASK (0x1F000000U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_EN_DLYD_REG_LINES_SHIFT (24U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_EN_DLYD_REG_LINES(x) (((uint32_t)(((uint32_t)(x)) << AI_WELL_LEVEL_SOURCE_CTRL0_EN_DLYD_REG_LINES_SHIFT)) & AI_WELL_LEVEL_SOURCE_CTRL0_EN_DLYD_REG_LINES_MASK)
#define AI_WELL_LEVEL_SOURCE_CTRL0_ASYM_BIAS_MASK (0xC0000000U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_ASYM_BIAS_SHIFT (30U)
#define AI_WELL_LEVEL_SOURCE_CTRL0_ASYM_BIAS(x) (((uint32_t)(((uint32_t)(x)) << AI_WELL_LEVEL_SOURCE_CTRL0_ASYM_BIAS_SHIFT)) & AI_WELL_LEVEL_SOURCE_CTRL0_ASYM_BIAS_MASK)

#define AI_BANDGAP_REF_CTRL0_REFTOP_PWD_MASK (0x1U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_PWD_SHIFT (0U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_PWD(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_PWD_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_PWD_MASK)
#define AI_BANDGAP_REF_CTRL0_REFTOP_LINREGREF_PWD_MASK (0x2U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_LINREGREF_PWD_SHIFT (1U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_LINREGREF_PWD(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_LINREGREF_PWD_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_LINREGREF_PWD_MASK)
#define AI_BANDGAP_REF_CTRL0_REFTOP_PWDVBGUP_MASK (0x4U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_PWDVBGUP_SHIFT (2U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_PWDVBGUP(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_PWDVBGUP_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_PWDVBGUP_MASK)
#define AI_BANDGAP_REF_CTRL0_REFTOP_LOWPOWER_MASK (0x8U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_LOWPOWER_SHIFT (3U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_LOWPOWER(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_LOWPOWER_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_LOWPOWER_MASK)
#define AI_BANDGAP_REF_CTRL0_REFTOP_SELFBIASOFF_MASK (0x10U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_SELFBIASOFF_SHIFT (4U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_SELFBIASOFF(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_SELFBIASOFF_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_SELFBIASOFF_MASK)
#define AI_BANDGAP_REF_CTRL0_REFTOP_VBGADJ_MASK (0xE0U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_VBGADJ_SHIFT (5U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_VBGADJ(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_VBGADJ_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_VBGADJ_MASK)
#define AI_BANDGAP_REF_CTRL0_REFTOP_BIAS_TST_MASK (0x300U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_BIAS_TST_SHIFT (8U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_BIAS_TST(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_BIAS_TST_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_BIAS_TST_MASK)
#define AI_BANDGAP_REF_CTRL0_REFTOP_IBZTCADJ_MASK (0x1C00U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_IBZTCADJ_SHIFT (10U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_IBZTCADJ(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_IBZTCADJ_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_IBZTCADJ_MASK)
#define AI_BANDGAP_REF_CTRL0_REFTOP_ANATEST_MASK (0x1E000U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_ANATEST_SHIFT (13U)
#define AI_BANDGAP_REF_CTRL0_REFTOP_ANATEST(x) (((uint32_t)(((uint32_t)(x)) << AI_BANDGAP_REF_CTRL0_REFTOP_ANATEST_SHIFT)) & AI_BANDGAP_REF_CTRL0_REFTOP_ANATEST_MASK)
#define AI_BANDGAP_REF_STAT0_REFTOP_VBGUP_MASK (0x1U)
#define AI_BANDGAP_REF_STAT0_REFTOP_VBGUP_SHIFT (0U)
#define AI_BANDGAP_REF_STAT0_REFTOP_VBGUP(x) ((uint32_t)((((uint32_t)(x)) & AI_BANDGAP_REF_STAT0_REFTOP_VBGUP_MASK) >> AI_BANDGAP_REF_STAT0_REFTOP_VBGUP_SHIFT))
#define AI_BANDGAP_REF_STAT0_VDD1_PORB_MASK (0x2U)
#define AI_BANDGAP_REF_STAT0_VDD1_PORB_SHIFT (1U)
#define AI_BANDGAP_REF_STAT0_VDD1_PORB(x) ((uint32_t)((((uint32_t)(x)) & AI_BANDGAP_REF_STAT0_VDD1_PORB_MASK) >> AI_BANDGAP_REF_STAT0_VDD1_PORB_SHIFT))
#define AI_BANDGAP_REF_STAT0_VDD2_PORB_MASK (0x4U)
#define AI_BANDGAP_REF_STAT0_VDD2_PORB_SHIFT (2U)
#define AI_BANDGAP_REF_STAT0_VDD2_PORB(x) ((uint32_t)((((uint32_t)(x)) & AI_BANDGAP_REF_STAT0_VDD2_PORB_MASK) >> AI_BANDGAP_REF_STAT0_VDD2_PORB_SHIFT))
#define AI_BANDGAP_REF_STAT0_VDD3_PORB_MASK (0x8U)
#define AI_BANDGAP_REF_STAT0_VDD3_PORB_SHIFT (3U)
#define AI_BANDGAP_REF_STAT0_VDD3_PORB(x) ((uint32_t)((((uint32_t)(x)) & AI_BANDGAP_REF_STAT0_VDD3_PORB_MASK) >> AI_BANDGAP_REF_STAT0_VDD3_PORB_SHIFT))

#define AI_VA_REFGEN_CTRL0_REFGEN_TRIM_MASK (0xFFU)
#define AI_VA_REFGEN_CTRL0_REFGEN_TRIM_SHIFT (0U)
#define AI_VA_REFGEN_CTRL0_REFGEN_TRIM(x) (((uint32_t)(((uint32_t)(x)) << AI_VA_REFGEN_CTRL0_REFGEN_TRIM_SHIFT)) & AI_VA_REFGEN_CTRL0_REFGEN_TRIM_MASK)
#define AI_VA_REFGEN_CTRL0_REFGEN_ANATEST_MASK (0x700U)
#define AI_VA_REFGEN_CTRL0_REFGEN_ANATEST_SHIFT (8U)
#define AI_VA_REFGEN_CTRL0_REFGEN_ANATEST(x) (((uint32_t)(((uint32_t)(x)) << AI_VA_REFGEN_CTRL0_REFGEN_ANATEST_SHIFT)) & AI_VA_REFGEN_CTRL0_REFGEN_ANATEST_MASK)
#define AI_VA_REFGEN_CTRL0_REFGEN_EN_MASK (0x800U)
#define AI_VA_REFGEN_CTRL0_REFGEN_EN_SHIFT (11U)
#define AI_VA_REFGEN_CTRL0_REFGEN_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_VA_REFGEN_CTRL0_REFGEN_EN_SHIFT)) & AI_VA_REFGEN_CTRL0_REFGEN_EN_MASK)
#define AI_VA_REFGEN_STAT0_REFGEN_SZ_MASK (0x1U)
#define AI_VA_REFGEN_STAT0_REFGEN_SZ_SHIFT (0U)
#define AI_VA_REFGEN_STAT0_REFGEN_SZ(x) ((uint32_t)((((uint32_t)(x)) & AI_VA_REFGEN_STAT0_REFGEN_SZ_MASK) >> AI_VA_REFGEN_STAT0_REFGEN_SZ_SHIFT))

#define AI_DIFFCLK_RPTR_CTRL0_PWDB_MASK (0x1U)
#define AI_DIFFCLK_RPTR_CTRL0_PWDB_SHIFT (0U)
#define AI_DIFFCLK_RPTR_CTRL0_PWDB(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_PWDB_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_PWDB_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_PWDB_CLKPATH_MASK (0x2U)
#define AI_DIFFCLK_RPTR_CTRL0_PWDB_CLKPATH_SHIFT (1U)
#define AI_DIFFCLK_RPTR_CTRL0_PWDB_CLKPATH(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_PWDB_CLKPATH_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_PWDB_CLKPATH_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_PWDB_REG1P0A_MASK (0x4U)
#define AI_DIFFCLK_RPTR_CTRL0_PWDB_REG1P0A_SHIFT (2U)
#define AI_DIFFCLK_RPTR_CTRL0_PWDB_REG1P0A(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_PWDB_REG1P0A_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_PWDB_REG1P0A_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_CLKOUT_SEL_MASK (0x10U)
#define AI_DIFFCLK_RPTR_CTRL0_CLKOUT_SEL_SHIFT (4U)
#define AI_DIFFCLK_RPTR_CTRL0_CLKOUT_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_CLKOUT_SEL_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_CLKOUT_SEL_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_REG1P0A_ADJ_MASK (0xE0U)
#define AI_DIFFCLK_RPTR_CTRL0_REG1P0A_ADJ_SHIFT (5U)
#define AI_DIFFCLK_RPTR_CTRL0_REG1P0A_ADJ(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_REG1P0A_ADJ_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_REG1P0A_ADJ_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR0_MASK (0x300U)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR0_SHIFT (8U)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR0(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_DRV_CUR0_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_DRV_CUR0_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR1_MASK (0xC00U)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR1_SHIFT (10U)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR1(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_DRV_CUR1_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_DRV_CUR1_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_TERM_RES_MASK (0x3000U)
#define AI_DIFFCLK_RPTR_CTRL0_TERM_RES_SHIFT (12U)
#define AI_DIFFCLK_RPTR_CTRL0_TERM_RES(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_TERM_RES_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_TERM_RES_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR_IN_MASK (0xC000U)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR_IN_SHIFT (14U)
#define AI_DIFFCLK_RPTR_CTRL0_DRV_CUR_IN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_DRV_CUR_IN_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_DRV_CUR_IN_MASK)
#define AI_DIFFCLK_RPTR_CTRL0_EN_VDDA1P0_TEST_MASK (0x80000000U)
#define AI_DIFFCLK_RPTR_CTRL0_EN_VDDA1P0_TEST_SHIFT (31U)
#define AI_DIFFCLK_RPTR_CTRL0_EN_VDDA1P0_TEST(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_RPTR_CTRL0_EN_VDDA1P0_TEST_SHIFT)) & AI_DIFFCLK_RPTR_CTRL0_EN_VDDA1P0_TEST_MASK)

#define AI_DIFFCLK_ROOT_CTRL0_PWDB_MASK (0x1U)
#define AI_DIFFCLK_ROOT_CTRL0_PWDB_SHIFT (0U)
#define AI_DIFFCLK_ROOT_CTRL0_PWDB(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_PWDB_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_PWDB_MASK)
#define AI_DIFFCLK_ROOT_CTRL0_PWDB_CLKPATH_MASK (0x2U)
#define AI_DIFFCLK_ROOT_CTRL0_PWDB_CLKPATH_SHIFT (1U)
#define AI_DIFFCLK_ROOT_CTRL0_PWDB_CLKPATH(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_PWDB_CLKPATH_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_PWDB_CLKPATH_MASK)
#define AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_MASK (0x4U)
#define AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_SHIFT (2U)
#define AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_MASK)
#define AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_DIFF_MASK (0x8U)
#define AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_DIFF_SHIFT (3U)
#define AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_DIFF(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_DIFF_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_CLKMUX_ENABLE_DIFF_MASK)
#define AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_DIFF_MASK (0x10U)
#define AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_DIFF_SHIFT (4U)
#define AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_DIFF(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_DIFF_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_DIFF_MASK)
#define AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_SE_MASK (0x20U)
#define AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_SE_SHIFT (5U)
#define AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_SE(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_SE_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_CLKIN_SEL_SE_MASK)
#define AI_DIFFCLK_ROOT_CTRL0_XTALIN_ISO_B_MASK (0x40U)
#define AI_DIFFCLK_ROOT_CTRL0_XTALIN_ISO_B_SHIFT (6U)
#define AI_DIFFCLK_ROOT_CTRL0_XTALIN_ISO_B(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_XTALIN_ISO_B_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_XTALIN_ISO_B_MASK)
#define AI_DIFFCLK_ROOT_CTRL0_DRV_CUR0_MASK (0x300U)
#define AI_DIFFCLK_ROOT_CTRL0_DRV_CUR0_SHIFT (8U)
#define AI_DIFFCLK_ROOT_CTRL0_DRV_CUR0(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_DRV_CUR0_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_DRV_CUR0_MASK)
#define AI_DIFFCLK_ROOT_CTRL0_DRV_CUR1_MASK (0xC00U)
#define AI_DIFFCLK_ROOT_CTRL0_DRV_CUR1_SHIFT (10U)
#define AI_DIFFCLK_ROOT_CTRL0_DRV_CUR1(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_ROOT_CTRL0_DRV_CUR1_SHIFT)) & AI_DIFFCLK_ROOT_CTRL0_DRV_CUR1_MASK)

#define AI_DIFFCLK_TERM_CTRL0_PWDB_MASK (0x1U)
#define AI_DIFFCLK_TERM_CTRL0_PWDB_SHIFT (0U)
#define AI_DIFFCLK_TERM_CTRL0_PWDB(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_TERM_CTRL0_PWDB_SHIFT)) & AI_DIFFCLK_TERM_CTRL0_PWDB_MASK)
#define AI_DIFFCLK_TERM_CTRL0_PWDB_CLKPATH_MASK (0x2U)
#define AI_DIFFCLK_TERM_CTRL0_PWDB_CLKPATH_SHIFT (1U)
#define AI_DIFFCLK_TERM_CTRL0_PWDB_CLKPATH(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_TERM_CTRL0_PWDB_CLKPATH_SHIFT)) & AI_DIFFCLK_TERM_CTRL0_PWDB_CLKPATH_MASK)
#define AI_DIFFCLK_TERM_CTRL0_CLKOUT_SEL_MASK (0x10U)
#define AI_DIFFCLK_TERM_CTRL0_CLKOUT_SEL_SHIFT (4U)
#define AI_DIFFCLK_TERM_CTRL0_CLKOUT_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_TERM_CTRL0_CLKOUT_SEL_SHIFT)) & AI_DIFFCLK_TERM_CTRL0_CLKOUT_SEL_MASK)
#define AI_DIFFCLK_TERM_CTRL0_TERM_RES_MASK (0x300U)
#define AI_DIFFCLK_TERM_CTRL0_TERM_RES_SHIFT (8U)
#define AI_DIFFCLK_TERM_CTRL0_TERM_RES(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_TERM_CTRL0_TERM_RES_SHIFT)) & AI_DIFFCLK_TERM_CTRL0_TERM_RES_MASK)
#define AI_DIFFCLK_TERM_CTRL0_SQRUP_CUR_MASK (0xC00U)
#define AI_DIFFCLK_TERM_CTRL0_SQRUP_CUR_SHIFT (10U)
#define AI_DIFFCLK_TERM_CTRL0_SQRUP_CUR(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_TERM_CTRL0_SQRUP_CUR_SHIFT)) & AI_DIFFCLK_TERM_CTRL0_SQRUP_CUR_MASK)
#define AI_DIFFCLK_TERM_CTRL0_DRV_CUR_IN_MASK (0x3000U)
#define AI_DIFFCLK_TERM_CTRL0_DRV_CUR_IN_SHIFT (12U)
#define AI_DIFFCLK_TERM_CTRL0_DRV_CUR_IN(x) (((uint32_t)(((uint32_t)(x)) << AI_DIFFCLK_TERM_CTRL0_DRV_CUR_IN_SHIFT)) & AI_DIFFCLK_TERM_CTRL0_DRV_CUR_IN_MASK)

#define AI_AV_PLL_CTRL0_DIV_SELECT_MASK (0x7FU)
#define AI_AV_PLL_CTRL0_DIV_SELECT_SHIFT (0U)
#define AI_AV_PLL_CTRL0_DIV_SELECT(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_DIV_SELECT_SHIFT)) & AI_AV_PLL_CTRL0_DIV_SELECT_MASK)
#define AI_AV_PLL_CTRL0_ENABLE_ALT_MASK (0x100U)
#define AI_AV_PLL_CTRL0_ENABLE_ALT_SHIFT (8U)
#define AI_AV_PLL_CTRL0_ENABLE_ALT(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_ENABLE_ALT_SHIFT)) & AI_AV_PLL_CTRL0_ENABLE_ALT_MASK)
#define AI_AV_PLL_CTRL0_HALF_LF_MASK (0x200U)
#define AI_AV_PLL_CTRL0_HALF_LF_SHIFT (9U)
#define AI_AV_PLL_CTRL0_HALF_LF(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_HALF_LF_SHIFT)) & AI_AV_PLL_CTRL0_HALF_LF_MASK)
#define AI_AV_PLL_CTRL0_DOUBLE_LF_MASK (0x400U)
#define AI_AV_PLL_CTRL0_DOUBLE_LF_SHIFT (10U)
#define AI_AV_PLL_CTRL0_DOUBLE_LF(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_DOUBLE_LF_SHIFT)) & AI_AV_PLL_CTRL0_DOUBLE_LF_MASK)
#define AI_AV_PLL_CTRL0_HALF_CP_MASK (0x800U)
#define AI_AV_PLL_CTRL0_HALF_CP_SHIFT (11U)
#define AI_AV_PLL_CTRL0_HALF_CP(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_HALF_CP_SHIFT)) & AI_AV_PLL_CTRL0_HALF_CP_MASK)
#define AI_AV_PLL_CTRL0_DOUBLE_CP_MASK (0x1000U)
#define AI_AV_PLL_CTRL0_DOUBLE_CP_SHIFT (12U)
#define AI_AV_PLL_CTRL0_DOUBLE_CP(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_DOUBLE_CP_SHIFT)) & AI_AV_PLL_CTRL0_DOUBLE_CP_MASK)
#define AI_AV_PLL_CTRL0_HOLD_RING_OFF_MASK (0x2000U)
#define AI_AV_PLL_CTRL0_HOLD_RING_OFF_SHIFT (13U)
#define AI_AV_PLL_CTRL0_HOLD_RING_OFF(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_HOLD_RING_OFF_SHIFT)) & AI_AV_PLL_CTRL0_HOLD_RING_OFF_MASK)
#define AI_AV_PLL_CTRL0_POWERUP_MASK (0x4000U)
#define AI_AV_PLL_CTRL0_POWERUP_SHIFT (14U)
#define AI_AV_PLL_CTRL0_POWERUP(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_POWERUP_SHIFT)) & AI_AV_PLL_CTRL0_POWERUP_MASK)
#define AI_AV_PLL_CTRL0_ENABLE_MASK (0x8000U)
#define AI_AV_PLL_CTRL0_ENABLE_SHIFT (15U)
#define AI_AV_PLL_CTRL0_ENABLE(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_ENABLE_SHIFT)) & AI_AV_PLL_CTRL0_ENABLE_MASK)
#define AI_AV_PLL_CTRL0_BYPASS_MASK (0x10000U)
#define AI_AV_PLL_CTRL0_BYPASS_SHIFT (16U)
#define AI_AV_PLL_CTRL0_BYPASS(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_BYPASS_SHIFT)) & AI_AV_PLL_CTRL0_BYPASS_MASK)
#define AI_AV_PLL_CTRL0_DITHER_EN_MASK (0x20000U)
#define AI_AV_PLL_CTRL0_DITHER_EN_SHIFT (17U)
#define AI_AV_PLL_CTRL0_DITHER_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_DITHER_EN_SHIFT)) & AI_AV_PLL_CTRL0_DITHER_EN_MASK)
#define AI_AV_PLL_CTRL0_PFD_OFFSET_EN_MASK (0x40000U)
#define AI_AV_PLL_CTRL0_PFD_OFFSET_EN_SHIFT (18U)
#define AI_AV_PLL_CTRL0_PFD_OFFSET_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_PFD_OFFSET_EN_SHIFT)) & AI_AV_PLL_CTRL0_PFD_OFFSET_EN_MASK)
#define AI_AV_PLL_CTRL0_BIAS_TRIM_MASK (0x380000U)
#define AI_AV_PLL_CTRL0_BIAS_TRIM_SHIFT (19U)
#define AI_AV_PLL_CTRL0_BIAS_TRIM(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_BIAS_TRIM_SHIFT)) & AI_AV_PLL_CTRL0_BIAS_TRIM_MASK)
#define AI_AV_PLL_CTRL0_PLL_REG_EN_MASK (0x400000U)
#define AI_AV_PLL_CTRL0_PLL_REG_EN_SHIFT (22U)
#define AI_AV_PLL_CTRL0_PLL_REG_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_PLL_REG_EN_SHIFT)) & AI_AV_PLL_CTRL0_PLL_REG_EN_MASK)
#define AI_AV_PLL_CTRL0_REGULATOR_VOLT_TRIM_MASK (0x1800000U)
#define AI_AV_PLL_CTRL0_REGULATOR_VOLT_TRIM_SHIFT (23U)
#define AI_AV_PLL_CTRL0_REGULATOR_VOLT_TRIM(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_REGULATOR_VOLT_TRIM_SHIFT)) & AI_AV_PLL_CTRL0_REGULATOR_VOLT_TRIM_MASK)
#define AI_AV_PLL_CTRL0_POST_DIV_SEL_MASK (0xE000000U)
#define AI_AV_PLL_CTRL0_POST_DIV_SEL_SHIFT (25U)
#define AI_AV_PLL_CTRL0_POST_DIV_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_POST_DIV_SEL_SHIFT)) & AI_AV_PLL_CTRL0_POST_DIV_SEL_MASK)
#define AI_AV_PLL_CTRL0_TEST_MODE_MASK (0x40000000U)
#define AI_AV_PLL_CTRL0_TEST_MODE_SHIFT (30U)
#define AI_AV_PLL_CTRL0_TEST_MODE(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_TEST_MODE_SHIFT)) & AI_AV_PLL_CTRL0_TEST_MODE_MASK)
#define AI_AV_PLL_CTRL0_TEST_MUX_ENABLE_MASK (0x80000000U)
#define AI_AV_PLL_CTRL0_TEST_MUX_ENABLE_SHIFT (31U)
#define AI_AV_PLL_CTRL0_TEST_MUX_ENABLE(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_CTRL0_TEST_MUX_ENABLE_SHIFT)) & AI_AV_PLL_CTRL0_TEST_MUX_ENABLE_MASK)
#define AI_AV_PLL_SPREAD_SPECTRUM_STEP_MASK (0x7FFFU)
#define AI_AV_PLL_SPREAD_SPECTRUM_STEP_SHIFT (0U)
#define AI_AV_PLL_SPREAD_SPECTRUM_STEP(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_SPREAD_SPECTRUM_STEP_SHIFT)) & AI_AV_PLL_SPREAD_SPECTRUM_STEP_MASK)
#define AI_AV_PLL_SPREAD_SPECTRUM_ENABLE_MASK (0x8000U)
#define AI_AV_PLL_SPREAD_SPECTRUM_ENABLE_SHIFT (15U)
#define AI_AV_PLL_SPREAD_SPECTRUM_ENABLE(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_SPREAD_SPECTRUM_ENABLE_SHIFT)) & AI_AV_PLL_SPREAD_SPECTRUM_ENABLE_MASK)
#define AI_AV_PLL_SPREAD_SPECTRUM_STOP_MASK (0xFFFF0000U)
#define AI_AV_PLL_SPREAD_SPECTRUM_STOP_SHIFT (16U)
#define AI_AV_PLL_SPREAD_SPECTRUM_STOP(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_SPREAD_SPECTRUM_STOP_SHIFT)) & AI_AV_PLL_SPREAD_SPECTRUM_STOP_MASK)
#define AI_AV_PLL_NUMERATOR_NUM_MASK (0x3FFFFFFFU)
#define AI_AV_PLL_NUMERATOR_NUM_SHIFT (0U)
#define AI_AV_PLL_NUMERATOR_NUM(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_NUMERATOR_NUM_SHIFT)) & AI_AV_PLL_NUMERATOR_NUM_MASK)
#define AI_AV_PLL_DENOMINATOR_DENOM_MASK (0x3FFFFFFFU)
#define AI_AV_PLL_DENOMINATOR_DENOM_SHIFT (0U)
#define AI_AV_PLL_DENOMINATOR_DENOM(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_DENOMINATOR_DENOM_SHIFT)) & AI_AV_PLL_DENOMINATOR_DENOM_MASK)

#define AI_AV_PLL_STAT0_REG_MASK (0xFFFFFFFFU)
#define AI_AV_PLL_STAT0_REG_SHIFT (0U)
#define AI_AV_PLL_STAT0_REG(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_STAT0_REG_SHIFT)) & AI_AV_PLL_STAT0_REG_MASK)

#define AI_AV_PLL_STAT1_REG_MASK (0xFFFFFFFFU)
#define AI_AV_PLL_STAT1_REG_SHIFT (0U)
#define AI_AV_PLL_STAT1_REG(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_STAT1_REG_SHIFT)) & AI_AV_PLL_STAT1_REG_MASK)
#define AI_AV_PLL_STAT2_REG_MASK (0xFFFFFFFFU)
#define AI_AV_PLL_STAT2_REG_SHIFT (0U)
#define AI_AV_PLL_STAT2_REG(x) (((uint32_t)(((uint32_t)(x)) << AI_AV_PLL_STAT1_REG_SHIFT)) & AI_AV_PLL_STAT1_REG_MASK)

#define AI_MLB_PLL_CTRL0_PLL_REG_ENABLE_MASK (0x1U)
#define AI_MLB_PLL_CTRL0_PLL_REG_ENABLE_SHIFT (0U)
#define AI_MLB_PLL_CTRL0_PLL_REG_ENABLE(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_PLL_REG_ENABLE_SHIFT)) & AI_MLB_PLL_CTRL0_PLL_REG_ENABLE_MASK)
#define AI_MLB_PLL_CTRL0_POWERUP_MASK (0x2U)
#define AI_MLB_PLL_CTRL0_POWERUP_SHIFT (1U)
#define AI_MLB_PLL_CTRL0_POWERUP(x)  (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_POWERUP_SHIFT)) & AI_MLB_PLL_CTRL0_POWERUP_MASK)
#define AI_MLB_PLL_CTRL0_MLBPLL_ENABLE_MASK (0x4U)
#define AI_MLB_PLL_CTRL0_MLBPLL_ENABLE_SHIFT (2U)
#define AI_MLB_PLL_CTRL0_MLBPLL_ENABLE(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_MLBPLL_ENABLE_SHIFT)) & AI_MLB_PLL_CTRL0_MLBPLL_ENABLE_MASK)
#define AI_MLB_PLL_CTRL0_MLBPLL_BYPASS_MASK (0x8U)
#define AI_MLB_PLL_CTRL0_MLBPLL_BYPASS_SHIFT (3U)
#define AI_MLB_PLL_CTRL0_MLBPLL_BYPASS(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_MLBPLL_BYPASS_SHIFT)) & AI_MLB_PLL_CTRL0_MLBPLL_BYPASS_MASK)
#define AI_MLB_PLL_CTRL0_LVDS_SRC_CLK_EN_MLB_PLL_MASK (0x10U)
#define AI_MLB_PLL_CTRL0_LVDS_SRC_CLK_EN_MLB_PLL_SHIFT (4U)
#define AI_MLB_PLL_CTRL0_LVDS_SRC_CLK_EN_MLB_PLL(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_LVDS_SRC_CLK_EN_MLB_PLL_SHIFT)) & AI_MLB_PLL_CTRL0_LVDS_SRC_CLK_EN_MLB_PLL_MASK)
#define AI_MLB_PLL_CTRL0_DOUBLE_CP_CURRENT_MASK (0x20U)
#define AI_MLB_PLL_CTRL0_DOUBLE_CP_CURRENT_SHIFT (5U)
#define AI_MLB_PLL_CTRL0_DOUBLE_CP_CURRENT(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_DOUBLE_CP_CURRENT_SHIFT)) & AI_MLB_PLL_CTRL0_DOUBLE_CP_CURRENT_MASK)
#define AI_MLB_PLL_CTRL0_HALF_CP_CURRENT_MASK (0x40U)
#define AI_MLB_PLL_CTRL0_HALF_CP_CURRENT_SHIFT (6U)
#define AI_MLB_PLL_CTRL0_HALF_CP_CURRENT(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_HALF_CP_CURRENT_SHIFT)) & AI_MLB_PLL_CTRL0_HALF_CP_CURRENT_MASK)
#define AI_MLB_PLL_CTRL0_HOLD_RING_OFF_MASK (0x80U)
#define AI_MLB_PLL_CTRL0_HOLD_RING_OFF_SHIFT (7U)
#define AI_MLB_PLL_CTRL0_HOLD_RING_OFF(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_HOLD_RING_OFF_SHIFT)) & AI_MLB_PLL_CTRL0_HOLD_RING_OFF_MASK)
#define AI_MLB_PLL_CTRL0_MLB_PLL_DIV_CFG_MASK (0x300U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_DIV_CFG_SHIFT (8U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_DIV_CFG(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_MLB_PLL_DIV_CFG_SHIFT)) & AI_MLB_PLL_CTRL0_MLB_PLL_DIV_CFG_MASK)
#define AI_MLB_PLL_CTRL0_MLB_PLL_PHASE_SEL_MASK (0xC00U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_PHASE_SEL_SHIFT (10U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_PHASE_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_MLB_PLL_PHASE_SEL_SHIFT)) & AI_MLB_PLL_CTRL0_MLB_PLL_PHASE_SEL_MASK)
#define AI_MLB_PLL_CTRL0_MLB_PLL_RXCLK_DEL_CFG_MASK (0x7000U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_RXCLK_DEL_CFG_SHIFT (12U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_RXCLK_DEL_CFG(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_MLB_PLL_RXCLK_DEL_CFG_SHIFT)) & AI_MLB_PLL_CTRL0_MLB_PLL_RXCLK_DEL_CFG_MASK)
#define AI_MLB_PLL_CTRL0_MLB_PLL_VDDD_DELAY_CFG_MASK (0x70000U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_VDDD_DELAY_CFG_SHIFT (16U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_VDDD_DELAY_CFG(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_MLB_PLL_VDDD_DELAY_CFG_SHIFT)) & AI_MLB_PLL_CTRL0_MLB_PLL_VDDD_DELAY_CFG_MASK)
#define AI_MLB_PLL_CTRL0_MLB_PLL_FLT_RES_SEL_MASK (0x700000U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_FLT_RES_SEL_SHIFT (20U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_FLT_RES_SEL(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_MLB_PLL_FLT_RES_SEL_SHIFT)) & AI_MLB_PLL_CTRL0_MLB_PLL_FLT_RES_SEL_MASK)
#define AI_MLB_PLL_CTRL0_MLB_PLL_VDDA_DELAY_CFG_MASK (0x7000000U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_VDDA_DELAY_CFG_SHIFT (24U)
#define AI_MLB_PLL_CTRL0_MLB_PLL_VDDA_DELAY_CFG(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_MLB_PLL_VDDA_DELAY_CFG_SHIFT)) & AI_MLB_PLL_CTRL0_MLB_PLL_VDDA_DELAY_CFG_MASK)
#define AI_MLB_PLL_CTRL0_REGULATOR_VOLT_TRIM_MASK (0x18000000U)
#define AI_MLB_PLL_CTRL0_REGULATOR_VOLT_TRIM_SHIFT (27U)
#define AI_MLB_PLL_CTRL0_REGULATOR_VOLT_TRIM(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_REGULATOR_VOLT_TRIM_SHIFT)) & AI_MLB_PLL_CTRL0_REGULATOR_VOLT_TRIM_MASK)
#define AI_MLB_PLL_CTRL0_TEST_MUX_ENABLE_MASK (0x20000000U)
#define AI_MLB_PLL_CTRL0_TEST_MUX_ENABLE_SHIFT (29U)
#define AI_MLB_PLL_CTRL0_TEST_MUX_ENABLE(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_TEST_MUX_ENABLE_SHIFT)) & AI_MLB_PLL_CTRL0_TEST_MUX_ENABLE_MASK)
#define AI_MLB_PLL_CTRL0_TSTI_POWERUP_MASK (0x40000000U)
#define AI_MLB_PLL_CTRL0_TSTI_POWERUP_SHIFT (30U)
#define AI_MLB_PLL_CTRL0_TSTI_POWERUP(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_TSTI_POWERUP_SHIFT)) & AI_MLB_PLL_CTRL0_TSTI_POWERUP_MASK)
#define AI_MLB_PLL_CTRL0_TESTMODE_MASK (0x80000000U)
#define AI_MLB_PLL_CTRL0_TESTMODE_SHIFT (31U)
#define AI_MLB_PLL_CTRL0_TESTMODE(x) (((uint32_t)(((uint32_t)(x)) << AI_MLB_PLL_CTRL0_TESTMODE_SHIFT)) & AI_MLB_PLL_CTRL0_TESTMODE_MASK)

#define AI_PHY_LDO_CTRL0_LINREG_EN_MASK (0x1U)
#define AI_PHY_LDO_CTRL0_LINREG_EN_SHIFT (0U)
#define AI_PHY_LDO_CTRL0_LINREG_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_PHY_LDO_CTRL0_LINREG_EN_SHIFT)) & AI_PHY_LDO_CTRL0_LINREG_EN_MASK)
#define AI_PHY_LDO_CTRL0_LINREG_PWRUPLOAD_DIS_MASK (0x2U)
#define AI_PHY_LDO_CTRL0_LINREG_PWRUPLOAD_DIS_SHIFT (1U)
#define AI_PHY_LDO_CTRL0_LINREG_PWRUPLOAD_DIS(x) (((uint32_t)(((uint32_t)(x)) << AI_PHY_LDO_CTRL0_LINREG_PWRUPLOAD_DIS_SHIFT)) & AI_PHY_LDO_CTRL0_LINREG_PWRUPLOAD_DIS_MASK)
#define AI_PHY_LDO_CTRL0_LINREG_ILIMIT_EN_MASK (0x4U)
#define AI_PHY_LDO_CTRL0_LINREG_ILIMIT_EN_SHIFT (2U)
#define AI_PHY_LDO_CTRL0_LINREG_ILIMIT_EN(x) (((uint32_t)(((uint32_t)(x)) << AI_PHY_LDO_CTRL0_LINREG_ILIMIT_EN_SHIFT)) & AI_PHY_LDO_CTRL0_LINREG_ILIMIT_EN_MASK)
#define AI_PHY_LDO_CTRL0_LINREG_OUTPUT_TRG_MASK (0x1F0U)
#define AI_PHY_LDO_CTRL0_LINREG_OUTPUT_TRG_SHIFT (4U)
#define AI_PHY_LDO_CTRL0_LINREG_OUTPUT_TRG(x) (((uint32_t)(((uint32_t)(x)) << AI_PHY_LDO_CTRL0_LINREG_OUTPUT_TRG_SHIFT)) & AI_PHY_LDO_CTRL0_LINREG_OUTPUT_TRG_MASK)
#define AI_PHY_LDO_CTRL0_LINREG_ANATEST_MASK (0x7000U)
#define AI_PHY_LDO_CTRL0_LINREG_ANATEST_SHIFT (12U)
#define AI_PHY_LDO_CTRL0_LINREG_ANATEST(x) (((uint32_t)(((uint32_t)(x)) << AI_PHY_LDO_CTRL0_LINREG_ANATEST_SHIFT)) & AI_PHY_LDO_CTRL0_LINREG_ANATEST_MASK)
#define AI_PHY_LDO_CTRL0_LINREG_PHY_ISO_B_MASK (0x8000U)
#define AI_PHY_LDO_CTRL0_LINREG_PHY_ISO_B_SHIFT (15U)
#define AI_PHY_LDO_CTRL0_LINREG_PHY_ISO_B(x) (((uint32_t)(((uint32_t)(x)) << AI_PHY_LDO_CTRL0_LINREG_PHY_ISO_B_SHIFT)) & AI_PHY_LDO_CTRL0_LINREG_PHY_ISO_B_MASK)
#define AI_PHY_LDO_STAT0_LINREG_STAT_MASK (0xFU)
#define AI_PHY_LDO_STAT0_LINREG_STAT_SHIFT (0U)
#define AI_PHY_LDO_STAT0_LINREG_STAT(x) ((uint32_t)((((uint32_t)(x)) & AI_PHY_LDO_STAT0_LINREG_STAT_MASK) >> AI_PHY_LDO_STAT0_LINREG_STAT_SHIFT))

#endif
