/*
** ###################################################################
**     Processors:          MX8
**
**     Compilers:           GNU C Compiler
**
**     Abstract:
**         CMSIS Peripheral Access Layer for MX8
**
**     Copyright (c) 1997 - 2015 Freescale Semiconductor, Inc.
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of the copyright holder nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
** ###################################################################
*/

/*
 * WARNING! DO NOT EDIT THIS FILE DIRECTLY!
 *
 * This file was generated automatically and any changes may be lost.
 */
#ifndef HW_LPC_REGISTERS_H
#define HW_LPC_REGISTERS_H

/* ----------------------------------------------------------------------------
   -- LPC Peripheral Access Layer
   ---------------------------------------------------------------------------- */

#define LPC_NUM_STAGES  7

/*!
 * @addtogroup LPC_Peripheral_Access_Layer LPC Peripheral Access Layer
 * @{
 */

/** LPC_CTRL - Register Layout Typedef */
typedef struct {
    __IO uint32_t LPC_PC[LPC_NUM_STAGES];   /**< Power Control Register N, offset: 0x0 */
    __IO uint32_t LPC_CR;                   /**< Configuration Register, offset: 0x1C */
    __IO uint32_t LPC_ED[LPC_NUM_STAGES];   /**< Entry Delay Register N, offset: 0x20 */
    uint32_t RESERVED_0[1];
    __IO uint32_t LPC_XD[LPC_NUM_STAGES];   /**< Exit Delay Register N, offset: 0x40 */
} LPC_Type, *LPC_MemMapPtr;


/* ----------------------------------------------------------------------------
   -- LPC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LPC_Register_Masks LPC Register Masks
 * @{
 */

/* LPC_PC Bit Fields */
/* LPC_CR Bit Fields */
/* LPC_ED Bit Fields */
/* LPC_XD Bit Fields */

#define LPC_LOW_FANOUT_BIT           0U
#define LPC_HIGH_FANOUT_BIT          1U
#define LPC_INPUT_ISO_BIT            2U
#define LPC_OUTPUT_ISO_BIT           3U
#define LPC_SW_RESETN_BIT            4U
#define LPC_PD_CONTROL_BIT           8U
#define LPC_MEM_LS_CONTROL_BIT      10U
#define LPC_MEM_HS_CONTROL_BIT      11U
#define LPC_RFF_BIT                 12U
#define LPC_MEM_SLEEP_BIT           13U
#define LPC_MEM_STDBY_BIT           14U
#define LPC_MEM_IG_BIT              15U
#define LPC_TCM_SMALL_MA_BIT        16U
#define LPC_TCM_LARGE_MA_BIT        17U
#define LPC_CM4_SMALL_MA_BIT        18U
#define LPC_CM4_LARGE_MA_BIT        19U
#define LPC_NSR_SMALL_MA_BIT        20U
#define LPC_NSR_LARGE_MA_BIT        21U
#define LPC_CM0_RAM_SMALL_MA_BIT    22U
#define LPC_CM0_RAM_LARGE_MA_BIT    23U

#define LPC_LOW_FANOUT             BIT(LPC_LOW_FANOUT_BIT)
#define LPC_HIGH_FANOUT            BIT(LPC_HIGH_FANOUT_BIT)
#define LPC_INPUT_ISO              BIT(LPC_INPUT_ISO_BIT)
#define LPC_OUTPUT_ISO             BIT(LPC_OUTPUT_ISO_BIT)
#define LPC_SW_RESETN              BIT(LPC_SW_RESETN_BIT)
#define LPC_PD_CONTROL             BIT(LPC_PD_CONTROL_BIT)
#define LPC_MEM_LS_CONTROL         BIT(LPC_MEM_LS_CONTROL_BIT)
#define LPC_MEM_HS_CONTROL         BIT(LPC_MEM_HS_CONTROL_BIT)
#define LPC_RFF                    BIT(LPC_RFF_BIT)
#define LPC_MEM_SLEEP              BIT(LPC_MEM_SLEEP_BIT)
#define LPC_MEM_STDBY              BIT(LPC_MEM_STDBY_BIT)
#define LPC_MEM_IG                 BIT(LPC_MEM_IG_BIT)
#define LPC_TCM_SMALL_MA           BIT(LPC_TCM_SMALL_MA_BIT)
#define LPC_TCM_LARGE_MA           BIT(LPC_TCM_LARGE_MA_BIT)
#define LPC_CM4_SMALL_MA           BIT(LPC_CM4_SMALL_MA_BIT)
#define LPC_CM4_LARGE_MA           BIT(LPC_CM4_LARGE_MA_BIT)
#define LPC_NSR_SMALL_MA           BIT(LPC_NSR_SMALL_MA_BIT)
#define LPC_NSR_LARGE_MA           BIT(LPC_NSR_LARGE_MA_BIT)
#define LPC_CM0_RAM_SMALL_MA       BIT(LPC_CM0_RAM_SMALL_MA_BIT)
#define LPC_CM0_RAM_LARGE_MA       BIT(LPC_CM0_RAM_LARGE_MA_BIT)

#define LPC_CR__ROSC_DISABLE       0U
#define LPC_CR__PMIC_STBY          1U
#define LPC_CR__PWRCTRL_MUXSEL     2U
#define LPC_CR__LPC_CLOCK_SEL      4U
#define LPC_CR__LPC_CLOCK_STOP     6U
#define LPC_CR__LPC_CLOCK_GATE     7U

#define LPC_CLK_25M                0U
#define LPC_CLK_1M                 1U
#define LPC_CLK_32K                2U

typedef uint8_t clk_sel_t;

#define DSC_PWR_SEL                0U
#define LPC_PWR_SEL                1U

typedef uint8_t pwr_ctrl_mux_sel_t;

#define ROSC_EN                    0U
#define ROSC_DIS                   1U

typedef uint8_t rosc_dis_t;

#define PMIC_STDBY_NAST            0U
#define PMIC_STDBY_AST             1U

typedef uint8_t pmic_stdby_t;

/*!
 * @}
 */ /* end of group LPC_Register_Masks */


/** Peripheral LPC base pointer */
#define LPC                                         ((LPC_Type *)LPC_BASE)

/* ----------------------------------------------------------------------------
   -- LPC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LPC_Register_Accessor_Macros LPC - Register accessor macros
 * @{
 */




/*!
 * @}
 */ /* end of group LPC_Peripheral_Access_Layer */

#endif /* HW_LPC_REGISTERS_H */

/* EOF */

