/*
** ###################################################################
**     Processors:          MX8QM
**
**     Compilers:           GNU C Compiler
**
**     Abstract:
**         CMSIS Peripheral Access Layer for MX8QM
**
**     Copyright 2017-2018 NXP
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of the copyright holder nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
** ###################################################################
*/

#ifndef HW_FUSES_H
#define HW_FUSES_H

/*******************************************************************************
 * Macros
 ******************************************************************************/

#if !defined(NO_DEVICE_ACCESS)
    #define OTP_GET_FUSE_STATE(_REG, SHFT, MSK) \
        ((((uint32_t)(OTP->FUSE[(_REG)].RW)) >> (SHFT)) & (MSK))
#else
    #define OTP_GET_FUSE_STATE(_REG, SHFT, MSK)  \
        (((temp_fuses[(_REG)]) >> (SHFT)) & (MSK))
#endif

/*******************************************************************************
 * Definitions
 ******************************************************************************/

#define OTP_CAAM_DIS                OTP_GET_FUSE_STATE(0x003U,  0U, 0x00000001U)
#define OTP_IEE_DIS                 OTP_GET_FUSE_STATE(0x003U,  1U, 0x00000001U)
#define OTP_DTCP_DIS                OTP_GET_FUSE_STATE(0x003U,  2U, 0x00000001U)
#define OTP_HDCP_DIS                OTP_GET_FUSE_STATE(0x003U,  3U, 0x00000001U)
#define OTP_MMCAU_DIS               OTP_GET_FUSE_STATE(0x003U,  4U, 0x00000001U)
#define OTP_ARM_CRYPT_EXT           OTP_GET_FUSE_STATE(0x003U,  5U, 0x00000001U)
#define OTP_SNVS_DIS                OTP_GET_FUSE_STATE(0x003U, 10U, 0x00000001U)
#define OTP_SECO_CLOSED_83          OTP_GET_FUSE_STATE(0x003U, 12U, 0x00000001U)
#define OTP_SECO_SECURED_83         OTP_GET_FUSE_STATE(0x003U, 13U, 0x00000001U)
#define OTP_ATTEST_DIS              OTP_GET_FUSE_STATE(0x003U, 14U, 0x00000001U)
#define OTP_PUF_ENB                 OTP_GET_FUSE_STATE(0x003U, 15U, 0x00000001U)
#define OTP_FUSE_LIFE_CYCLE         OTP_GET_FUSE_STATE(0x004U,  0U, 0x000003FFU)
#define OTP_SDP_DIS                 OTP_GET_FUSE_STATE(0x004U, 10U, 0x00000001U)
#define OTP_SDP_W_ONLY              OTP_GET_FUSE_STATE(0x004U, 11U, 0x00000001U)
#define OTP_SREV_XOR                OTP_GET_FUSE_STATE(0x004U, 12U, 0x00000007U)
#define OTP_SREV_ROM                OTP_GET_FUSE_STATE(0x004U, 15U, 0x00000001U)
#define OTP_SJC_DIS                 OTP_GET_FUSE_STATE(0x005U,  0U, 0x00000001U)
#define OTP_JTAG_SEC_MODE           OTP_GET_FUSE_STATE(0x005U,  1U, 0x00000003U)
#define OTP_TZ_DBG_DIS              OTP_GET_FUSE_STATE(0x005U,  3U, 0x00000001U)
#define OTP_OEM_SEC_CONFIG          OTP_GET_FUSE_STATE(0x005U,  5U, 0x00000003U)
#define OTP_SCU_SEC_CONFIG          OTP_GET_FUSE_STATE(0x005U,  7U, 0x00000003U)
#define OTP_SECO_GLITCH_DET         OTP_GET_FUSE_STATE(0x005U,  9U, 0x00000001U)
#define OTP_OTP_CHLG_RESP_DIS       OTP_GET_FUSE_STATE(0x005U, 10U, 0x00000001U)
#define OTP_TZ_CHLG_RESP_DIS        OTP_GET_FUSE_STATE(0x005U, 11U, 0x00000001U)
#define OTP_ARRAY_IS_PROG           OTP_GET_FUSE_STATE(0x005U, 15U, 0x00000001U)
#define OTP_AP_0_DIS                OTP_GET_FUSE_STATE(0x006U,  0U, 0x0000000FU)                     
#define OTP_AP_0_0_DIS              OTP_GET_FUSE_STATE(0x006U,  0U, 0x00000001U)                     
#define OTP_AP_0_1_DIS              OTP_GET_FUSE_STATE(0x006U,  1U, 0x00000001U)                     
#define OTP_AP_0_2_DIS              OTP_GET_FUSE_STATE(0x006U,  2U, 0x00000001U)                     
#define OTP_AP_0_3_DIS              OTP_GET_FUSE_STATE(0x006U,  3U, 0x00000001U)                     
#define OTP_AP_1_DIS                OTP_GET_FUSE_STATE(0x006U,  4U, 0x00000003U)                     
#define OTP_AP_1_0_DIS              OTP_GET_FUSE_STATE(0x006U,  4U, 0x00000001U)                     
#define OTP_AP_1_1_DIS              OTP_GET_FUSE_STATE(0x006U,  5U, 0x00000001U)                     
#define OTP_AP_0_MAX_FREQ           OTP_GET_FUSE_STATE(0x006U,  8U, 0x0000000FU)                     
#define OTP_AP_1_MAX_FREQ           OTP_GET_FUSE_STATE(0x006U, 12U, 0x0000000FU)                     
#define OTP_GPU_0_DIS               OTP_GET_FUSE_STATE(0x007U,  0U, 0x00000001U)                     
#define OTP_GPU_1_DIS               OTP_GET_FUSE_STATE(0x007U,  1U, 0x00000001U)                     
#define OTP_GPU_MAX_FREQ            OTP_GET_FUSE_STATE(0x007U,  4U, 0x0000000FU)                     
#define OTP_DC_0_DIS                OTP_GET_FUSE_STATE(0x007U,  8U, 0x00000003U)                     
#define OTP_DC_1_DIS                OTP_GET_FUSE_STATE(0x007U, 10U, 0x00000003U)                     
#define OTP_VPU_DIS                 OTP_GET_FUSE_STATE(0x007U, 12U, 0x0000000FU)                     
#define OTP_VPU_ENC0_DIS            OTP_GET_FUSE_STATE(0x007U, 12U, 0x00000001U)                     
#define OTP_VPU_ENC1_DIS            OTP_GET_FUSE_STATE(0x007U, 13U, 0x00000001U)                     
#define OTP_VPU_DEC_DIS             OTP_GET_FUSE_STATE(0x007U, 14U, 0x00000003U)                     
#define OTP_DSP_DIS                 OTP_GET_FUSE_STATE(0x008U,  0U, 0x00000001U)                     
#define OTP_MCU_0_DIS               OTP_GET_FUSE_STATE(0x008U,  1U, 0x00000001U)                     
#define OTP_MCU_1_DIS               OTP_GET_FUSE_STATE(0x008U,  2U, 0x00000001U)                     
#define OTP_SATA_DIS                OTP_GET_FUSE_STATE(0x008U,  4U, 0x00000001U)                     
#define OTP_PCIE_A_DIS              OTP_GET_FUSE_STATE(0x008U,  5U, 0x00000001U)                     
#define OTP_PCIE_B_DIS              OTP_GET_FUSE_STATE(0x008U,  6U, 0x00000001U)                     
#define OTP_USB2_1_DIS              OTP_GET_FUSE_STATE(0x008U,  8U, 0x00000001U)
#define OTP_USB2_2_OTG_DIS          OTP_GET_FUSE_STATE(0x008U,  9U, 0x00000001U)
#define OTP_USB_SS_DIS              OTP_GET_FUSE_STATE(0x008U, 10U, 0x00000001U)
#define OTP_USB2_3_OTG_DIS          OTP_GET_FUSE_STATE(0x008U, 11U, 0x00000001U)
#define OTP_ETH_0_DIS               OTP_GET_FUSE_STATE(0x008U, 12U, 0x00000001U)
#define OTP_ETH_1_DIS               OTP_GET_FUSE_STATE(0x008U, 13U, 0x00000001U)
#define OTP_HDMI_TX_DIS             OTP_GET_FUSE_STATE(0x009U,  0U, 0x00000001U)                     
#define OTP_MIPI_0_DIS              OTP_GET_FUSE_STATE(0x009U,  1U, 0x00000001U)                     
#define OTP_MIPI_1_DIS              OTP_GET_FUSE_STATE(0x009U,  2U, 0x00000001U)                     
#define OTP_HDMI_RX_DIS             OTP_GET_FUSE_STATE(0x009U,  4U, 0x00000001U)                     
#define OTP_CSI_0_DIS               OTP_GET_FUSE_STATE(0x009U,  5U, 0x00000001U)                     
#define OTP_CSI_1_DIS               OTP_GET_FUSE_STATE(0x009U,  6U, 0x00000001U)                     
#define OTP_CSI_2_DIS               OTP_GET_FUSE_STATE(0x009U,  7U, 0x00000001U)                     
#define OTP_DRC_0_DIS               OTP_GET_FUSE_STATE(0x009U,  8U, 0x0000000FU)                     
#define OTP_DRC_1_DIS               OTP_GET_FUSE_STATE(0x009U, 12U, 0x0000000FU)                     
#define OTP_CAN_DIS                 OTP_GET_FUSE_STATE(0x00AU,  0U, 0x00000001U)                     
#define OTP_FIPS_MODE               OTP_GET_FUSE_STATE(0x00AU,  3U, 0x00000001U)                     
#define OTP_FIPS_MODE_DIS           OTP_GET_FUSE_STATE(0x00AU,  4U, 0x00000001U)                     

/////////////////////////////////////////////////////////////////////////////
#define OTP_ADM_SECURITY_MSKL       OTP_GET_FUSE_STATE(0x00CU,  0U, 0x0000FFFFU)
#define OTP_ADM_SECURITY_MSKU       OTP_GET_FUSE_STATE(0x00DU,  0U, 0x0000FFFFU)

#define OTP_FUSES_VALID             OTP_GET_FUSE_STATE(0x00EU,  0U, 0x00000007U)

#define OTP_ROM_CONTROL             OTP_GET_FUSE_STATE(0x00EU,  8U, 0x000000FFU)

#define OTP_READ_LOCKS              OTP_GET_FUSE_STATE(0x00FU,  0U, 0x000080FFU)

#define OTP_UNIQUE_ID_L             OTP_GET_FUSE_STATE(0x010U,  0U, 0xFFFFFFFFU)
#define OTP_UNIQUE_ID_H             OTP_GET_FUSE_STATE(0x011U,  0U, 0xFFFFFFFFU)

#define OTP_LOT_NUM_ENCL            OTP_GET_FUSE_STATE(0x010U,  0U, 0xFFFFFFFFU)
#define OTP_LOT_NUM_ENCU            OTP_GET_FUSE_STATE(0x011U,  0U, 0xFFFFFFFFU)

#define OTP_BOOT_MODE_FUSES         OTP_GET_FUSE_STATE(0x012U,  0U, 0xFFFFFFFFU)
#define OTP_USDHC_OPTIONS           OTP_GET_FUSE_STATE(0x013U,  0U, 0xFFFFFFFFU)
///////////////////////////////////////////////////////////////redo

#define OTP_PROG_FUSE_VERSION_AP_1_OPP      OTP_GET_FUSE_STATE(0x01bU,  0U,  0x00000001U)
#define OTP_PROG_FUSE_VERSION_SQRUP         OTP_GET_FUSE_STATE(0x01bU,  1U,  0x00000001U)
#define OTP_PROG_FUSE_VERSION_1_7V_CAL      OTP_GET_FUSE_STATE(0x01bU,  2U,  0x00000001U)
#define OTP_DPLL_CALIB_V2                   OTP_GET_FUSE_STATE(0x01bU,  3U,  0x00000001U)
#define OTP_PROG_FUSE_TRIM_LDO              OTP_GET_FUSE_STATE(0x01bU,  4U,  0x00000001U)
#define OTP_PROG_FUSE_GPU_NM_625            OTP_GET_FUSE_STATE(0x01bU,  7U,  0x00000001U)

#define OTP_OSC_CAP_TRM_32K         OTP_GET_FUSE_STATE(0x01eU,  0U,  0x0000000FU)
#define OTP_TMP_MON_TRM_LO          OTP_GET_FUSE_STATE(0x01eU,  4U,  0x0000003FU)
#define OTP_TMP_MON_TRM_HI          OTP_GET_FUSE_STATE(0x01eU,  10U, 0x0000003FU)
#define OTP_TMP_MON_TRM_RES         OTP_GET_FUSE_STATE(0x01eU,  16U, 0x0000000FU)
#define OTP_TMP_MON_TRM_SHLF_LO     OTP_GET_FUSE_STATE(0x01eU,  20U, 0x0000003FU)
#define OTP_TMP_MON_TRM_SHLF_HI     OTP_GET_FUSE_STATE(0x01eU,  26U, 0x0000003FU)
#define OTP_SNVS_BNDGAP_TRM         OTP_GET_FUSE_STATE(0x01fU,  0U,  0x0000001FU)
#define OTP_32K_IRC_TRM             OTP_GET_FUSE_STATE(0x01fU,  5U,  0x0000001FU)
#define OTP_CLK_MON_TRM_LO          OTP_GET_FUSE_STATE(0x01fU,  10U, 0x0000000FU)
#define OTP_CLK_MON_TRM_HI          OTP_GET_FUSE_STATE(0x01fU,  14U, 0x0000000FU)
#define OTP_V_MON_TRM_LO            OTP_GET_FUSE_STATE(0x01fU,  18U, 0x0000000FU)
#define OTP_V_MON_TRM_HI            OTP_GET_FUSE_STATE(0x01fU,  22U, 0x0000000FU)
#define OTP_V_MON_TAMP_DIS          OTP_GET_FUSE_STATE(0x01fU,  26U, 0x00000001U)
#define OTP_CLK_MON_DIS             OTP_GET_FUSE_STATE(0x01fU,  27U, 0x00000001U)
#define OTP_TMP_MON_DIS             OTP_GET_FUSE_STATE(0x01fU,  28U, 0x00000001U)
#define OTP_SNVS_CORE_V_TRM         OTP_GET_FUSE_STATE(0x01fU,  30U, 0x00000002U)

#define OTP_REFGEN_SCU              OTP_GET_FUSE_STATE(0x064U,  0U,  0x000000FFU)
#define OTP_REFGEN_AP_0             OTP_GET_FUSE_STATE(0x064U,  8U,  0x000000FFU)
#define OTP_REFGEN_AP_1             OTP_GET_FUSE_STATE(0x064U,  16U, 0x000000FFU)
#define OTP_REFGEN_DRC0             OTP_GET_FUSE_STATE(0x064U,  24U, 0x000000FFU)
#define OTP_REFGEN_DRC1             OTP_GET_FUSE_STATE(0x065U,  0U,  0x000000FFU)
#define OTP_REFGEN_GPU0             OTP_GET_FUSE_STATE(0x065U,  8U,  0x000000FFU)
#define OTP_REFGEN_GPU1             OTP_GET_FUSE_STATE(0x065U,  16U, 0x000000FFU)
#define OTP_REFGEN_DMA              OTP_GET_FUSE_STATE(0x065U,  24U, 0x000000FFU)
#define OTP_REFGEN_DI_CNCT          OTP_GET_FUSE_STATE(0x066U,  0U,  0x000000FFU)
#define OTP_REFGEN_DI_HDMI          OTP_GET_FUSE_STATE(0x066U,  8U,  0x000000FFU)
#define OTP_REFGEN_RX_HDMI          OTP_GET_FUSE_STATE(0x066U,  16U, 0x000000FFU)
#define OTP_REFGEN_HSIO             OTP_GET_FUSE_STATE(0x066U,  24U, 0x000000FFU)
#define OTP_REFGEN_VPU              OTP_GET_FUSE_STATE(0x069U,   0U, 0x000000FFU)

#define OTP_USB_PHY_TRM             OTP_GET_FUSE_STATE(0x067U,  0U,  0x000FFFFFU)
#define OTP_DSI0_TRM                OTP_GET_FUSE_STATE(0x067U,  20U, 0x00000003U)
#define OTP_DSI1_TRM                OTP_GET_FUSE_STATE(0x067U,  22U, 0x00000003U)
#define OTP_CHARGE_PUMP             OTP_GET_FUSE_STATE(0x067U,  27U, 0x0000001FU)
#define OTP_WLEVEL_BIAS_AP_0        OTP_GET_FUSE_STATE(0x068U,  0U,  0x000000FFU)
#define OTP_WLEVEL_BIAS_AP_1        OTP_GET_FUSE_STATE(0x068U,  8U,  0x000000FFU)
#define OTP_WLEVEL_BIAS_GPU0        OTP_GET_FUSE_STATE(0x068U,  16U, 0x000000FFU)
#define OTP_WLEVEL_BIAS_GPU1        OTP_GET_FUSE_STATE(0x068U,  24U, 0x000000FFU)
#define OTP_CSI0_TRM                OTP_GET_FUSE_STATE(0x069U,  8U,  0x00000003U)
#define OTP_CSI1_TRM                OTP_GET_FUSE_STATE(0x069U,  10U, 0x00000003U)
#define OTP_TMP_SENS_SCU            OTP_GET_FUSE_STATE(0x069U,  12U, 0x000003FFU)
#define OTP_TMP_SENS_AP_0           OTP_GET_FUSE_STATE(0x069U,  22U, 0x000003FFU)
#define OTP_TMP_SENS_AP_1           OTP_GET_FUSE_STATE(0x06aU,  2U,  0x000003FFU)
#define OTP_TMP_SENS_GPU0           OTP_GET_FUSE_STATE(0x06aU,  12U, 0x000003FFU)
#define OTP_TMP_SENS_GPU1           OTP_GET_FUSE_STATE(0x06aU,  22U, 0x000003FFU)
#define OTP_TMP_SENS_DRC0           OTP_GET_FUSE_STATE(0x06bU,  2U,  0x000003FFU)
#define OTP_TMP_SENS_DRC1           OTP_GET_FUSE_STATE(0x06bU,  12U, 0x000003FFU)
#define OTP_TMP_SENS_VPU            OTP_GET_FUSE_STATE(0x06bU,  22U, 0x000003FFU)

#define OTP_BIAS_AP_0_OD_COLD       OTP_GET_FUSE_STATE(0x06CU,  0U, 0x000000FFU)
#define OTP_BIAS_AP_1_OD_COLD       OTP_GET_FUSE_STATE(0x06CU,  8U, 0x000000FFU)
#define OTP_BIAS_GPX0_OD_COLD       OTP_GET_FUSE_STATE(0x06CU, 16U, 0x000000FFU)
#define OTP_BIAS_GPX1_OD_COLD       OTP_GET_FUSE_STATE(0x06CU, 24U, 0x000000FFU)
#define OTP_BIAS_GPX0_NM_COLD       OTP_GET_FUSE_STATE(0x06DU, 16U, 0x000000FFU)
#define OTP_BIAS_GPX1_NM_COLD       OTP_GET_FUSE_STATE(0x06DU, 24U, 0x000000FFU)

#define OTP_BIAS_AP_0_OD_HOT        OTP_GET_FUSE_STATE(0x06EU,  0U, 0x000000FFU)
#define OTP_BIAS_AP_1_OD_HOT        OTP_GET_FUSE_STATE(0x06EU,  8U, 0x000000FFU)
#define OTP_BIAS_GPX0_OD_HOT        OTP_GET_FUSE_STATE(0x06EU, 16U, 0x000000FFU)
#define OTP_BIAS_GPX1_OD_HOT        OTP_GET_FUSE_STATE(0x06EU, 24U, 0x000000FFU)
#define OTP_BIAS_GPX0_NM_HOT        OTP_GET_FUSE_STATE(0x06FU, 16U, 0x000000FFU)
#define OTP_BIAS_GPX1_NM_HOT        OTP_GET_FUSE_STATE(0x06FU, 24U, 0x000000FFU)

#define OTP_ROM_PATCH               0x070U
#define OTP_ROM_PATCH_SIZE          62U
#define OTP_V2X_PATCH_SIZE          0U

#define OTP_SINGLE_END_CLK          OTP_GET_FUSE_STATE(0x0AEU,  4U,  0x00000001U)

#define OTP_24MHZ_REGH_LV           OTP_GET_FUSE_STATE(0x100U,  0U, 0x00000007U)
#define OTP_24MHZ_REGL_LV           OTP_GET_FUSE_STATE(0x100U,  3U, 0x00000007U)
#define OTP_ROSC_FREQ_OFF           OTP_GET_FUSE_STATE(0x100U,  8U, 0x00FFFFFFU)

#define OTP_DPLL_TRM                OTP_GET_FUSE_STATE(0x101U,  0U,  0xFFFFFFFFU)
#define OTP_DPLL_TRM_VALID          OTP_GET_FUSE_STATE(0x101U,  0U,  0x00800000U)
#define OTP_t_SNVS_BNDGAP_TRM       OTP_GET_FUSE_STATE(0x104U,  8U,  0x0000001FU)
#define OTP_t_32K_INT_TRM           OTP_GET_FUSE_STATE(0x104U,  13U, 0x0000001FU)
#define OTP_t_TMP_SENS_SCU_0        OTP_GET_FUSE_STATE(0x104U,  20U, 0x000003FFU)
#define OTP_t_TMP_SENS_AP_0_1       OTP_GET_FUSE_STATE(0x105U,  6U,  0x000003FFU)
#define OTP_t_CHARGE_PUMP           OTP_GET_FUSE_STATE(0x105U,  27U, 0x0000001FU)
#define OTP_t_OSC_CAP_TRIM_32K      OTP_GET_FUSE_STATE(0x106U,  0U,  0x0000000FU)
#define OTP_t_TMP_MON_TRM_LO        OTP_GET_FUSE_STATE(0x106U,  4U,  0x0000003FU)
#define OTP_t_TMP_MON_TRM_HI        OTP_GET_FUSE_STATE(0x106U,  10U, 0x0000003FU)
#define OTP_t_TMP_MON_TRM_RES       OTP_GET_FUSE_STATE(0x106U,  16U, 0x0000000FU)
#define OTP_t_TMP_MON_SHLF_LO       OTP_GET_FUSE_STATE(0x106U,  20U, 0x0000003FU)
#define OTP_t_TMP_MON_SHLF_HI       OTP_GET_FUSE_STATE(0x106U,  26U, 0x0000003FU)
#define OTP_t_CLK_MON_TRM_LO        OTP_GET_FUSE_STATE(0x107U,  10U, 0x0000000FU)
#define OTP_t_CLK_MON_TRM_HI        OTP_GET_FUSE_STATE(0x107U,  14U, 0x0000000FU)
#define OTP_t_V_MON_TRM_LO          OTP_GET_FUSE_STATE(0x107U,  18U, 0x0000000FU)
#define OTP_t_V_MON_TRM_HI          OTP_GET_FUSE_STATE(0x107U,  22U, 0x0000000FU)
#define OTP_t_SNVS_CORE_V_TRM       OTP_GET_FUSE_STATE(0x107U,  30U, 0x0000000CU)

#define OTP_24MHZ_DIFF_VALID        OTP_GET_FUSE_STATE(0x102U, 31U, 0x00000001U)
#define OTP_24MHZ_DIFF_DRV0         OTP_GET_FUSE_STATE(0x102U,  0U, 0x00000003U)
#define OTP_24MHZ_DIFF_DRV1         OTP_GET_FUSE_STATE(0x102U,  4U, 0x00000003U)
#define OTP_24MHZ_DIFF_TERM_RES     OTP_GET_FUSE_STATE(0x102U,  8U, 0x00000003U)
#define OTP_24MHZ_DIFF_DRV_IN       OTP_GET_FUSE_STATE(0x102U, 10U, 0x00000003U)
#define OTP_24MHZ_DIFF_SQRUP        OTP_GET_FUSE_STATE(0x102U, 12U, 0x00000003U)
#define OTP_SCU_REG_TRIM            OTP_GET_FUSE_STATE(0x102U, 16U, 0x00000007U)
#define OTP_VPU_REG0_TRIM           OTP_GET_FUSE_STATE(0x102U, 19U, 0x00000007U)
#define OTP_VPU_REG1_TRIM           OTP_GET_FUSE_STATE(0x102U, 22U, 0x00000007U)

#define OTP_CSI_0_RCAL_TRIM         OTP_GET_FUSE_STATE(0x069U,  8U, 0x00000003U)
#define OTP_CSI_1_RCAL_TRIM         OTP_GET_FUSE_STATE(0x069U, 10U, 0x00000003U)
#define OTP_DSI_0_RCAL_TRIM         OTP_GET_FUSE_STATE(0x067U, 20U, 0x00000003U)
#define OTP_DSI_1_RCAL_TRIM         OTP_GET_FUSE_STATE(0x067U, 22U, 0x00000003U)

#define OTP_DSI_0_VOH_CLK_TRIM      OTP_GET_FUSE_STATE(0x103U,  0U, 0x00000007U)
#define OTP_DSI_0_VOH_D3_TRIM       OTP_GET_FUSE_STATE(0x103U,  3U, 0x00000007U)
#define OTP_DSI_0_VOH_D2_TRIM       OTP_GET_FUSE_STATE(0x103U,  6U, 0x00000007U)
#define OTP_DSI_0_VOH_D1_TRIM       OTP_GET_FUSE_STATE(0x103U,  9U, 0x00000007U)
#define OTP_DSI_0_VOH_D0_TRIM       OTP_GET_FUSE_STATE(0x103U, 12U, 0x00000007U)
#define OTP_DSI_1_VOH_CLK_TRIM      OTP_GET_FUSE_STATE(0x103U, 16U, 0x00000007U)
#define OTP_DSI_1_VOH_D3_TRIM       OTP_GET_FUSE_STATE(0x103U, 19U, 0x00000007U)
#define OTP_DSI_1_VOH_D2_TRIM       OTP_GET_FUSE_STATE(0x103U, 22U, 0x00000007U)
#define OTP_DSI_1_VOH_D1_TRIM       OTP_GET_FUSE_STATE(0x103U, 25U, 0x00000007U)
#define OTP_DSI_1_VOH_D0_TRIM       OTP_GET_FUSE_STATE(0x103U, 28U, 0x00000007U)

#define OTP_24MHZ_CL_TUNE_LV        OTP_GET_FUSE_STATE(0x1F0U,  0U, 0x000000FFU)
#define OTP_24MHZ_CL_TUNE_VALID     OTP_GET_FUSE_STATE(0x1F0U, 31U, 0x00000001U)

#define OTP_TMP_SENS_SCU_OFS        OTP_GET_FUSE_STATE(0x301U,  0U, 0x000000FFU)
#define OTP_TMP_SENS_AP_0_OFS       OTP_GET_FUSE_STATE(0x301U,  8U, 0x000000FFU)
#define OTP_TMP_SENS_AP_1_OFS       OTP_GET_FUSE_STATE(0x301U, 16U, 0x000000FFU)
#define OTP_TMP_SENS_GPU0_OFS       OTP_GET_FUSE_STATE(0x301U, 24U, 0x000000FFU)
#define OTP_TMP_SENS_GPU1_OFS       OTP_GET_FUSE_STATE(0x302U,  0U, 0x000000FFU)
#define OTP_TMP_SENS_DRC0_OFS       OTP_GET_FUSE_STATE(0x302U,  8U, 0x000000FFU)
#define OTP_TMP_SENS_DRC1_OFS       OTP_GET_FUSE_STATE(0x302U, 16U, 0x000000FFU)
#define OTP_TMP_SENS_VPU_OFS        OTP_GET_FUSE_STATE(0x302U, 24U, 0x000000FFU)

#define OTP_DPLL_TABLE_SELECT_VALID OTP_GET_FUSE_STATE(0x31DU, 31U, 0x00000001U)
#define OTP_DPLL_TABLE_SELECT_BITS  OTP_GET_FUSE_STATE(0x31DU,  0U, 0x003FFFFFU)

#define OTP_DPLL_TABLE_0_VALID      OTP_GET_FUSE_STATE(0x31EU, 31U, 0x00000001U)
#define OTP_DPLL_TABLE_0_V6         OTP_GET_FUSE_STATE(0x31EU, 26U, 0x0000001FU)
#define OTP_DPLL_TABLE_0_V5         OTP_GET_FUSE_STATE(0x31EU, 21U, 0x0000001FU)
#define OTP_DPLL_TABLE_0_V4         OTP_GET_FUSE_STATE(0x31EU, 16U, 0x0000001FU)
#define OTP_DPLL_TABLE_0_V3         OTP_GET_FUSE_STATE(0x31EU, 11U, 0x0000001FU)
#define OTP_DPLL_TABLE_0_V2         OTP_GET_FUSE_STATE(0x31EU,  6U, 0x0000001FU)
#define OTP_DPLL_TABLE_0_V1         OTP_GET_FUSE_STATE(0x31EU,  0U, 0x0000003FU)

#define OTP_DPLL_TABLE_1_VALID      OTP_GET_FUSE_STATE(0x31FU, 31U, 0x00000001U)
#define OTP_DPLL_TABLE_1_V6         OTP_GET_FUSE_STATE(0x31FU, 26U, 0x0000001FU)
#define OTP_DPLL_TABLE_1_V5         OTP_GET_FUSE_STATE(0x31FU, 21U, 0x0000001FU)
#define OTP_DPLL_TABLE_1_V4         OTP_GET_FUSE_STATE(0x31FU, 16U, 0x0000001FU)
#define OTP_DPLL_TABLE_1_V3         OTP_GET_FUSE_STATE(0x31FU, 11U, 0x0000001FU)
#define OTP_DPLL_TABLE_1_V2         OTP_GET_FUSE_STATE(0x31FU,  6U, 0x0000001FU)
#define OTP_DPLL_TABLE_1_V1         OTP_GET_FUSE_STATE(0x31FU,  0U, 0x0000003FU)

#endif /* HW_FUSES_H */

