/*
** ###################################################################
**
**     Copyright (c) 2016 Freescale Semiconductor, Inc.
**     Copyright 2017-2020 NXP
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of the copyright holder nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
** ###################################################################
*/

/*==========================================================================*/
/*!
 * @file
 *
 * File containing server-side RPC functions for the IRQ service.
 *
 * @addtogroup IRQ_SVC
 * @{
 */
/*==========================================================================*/

/* DO NOT EDIT - This file auto generated by bin/perl/rpc_srv_c.pl */

/* Includes */

#include "main/scfw.h"
#include "main/types.h"
#include "main/main.h"
#include "main/rpc.h"
#include "svc/irq/svc.h"
#include "svc/irq/rpc.h"

/* Local Defines */

/* Local Types */

/*--------------------------------------------------------------------------*/
/* Dispatch incoming RPC function call                                      */
/*--------------------------------------------------------------------------*/
void irq_dispatch(sc_rm_pt_t caller_pt, sc_rsrc_t mu, sc_rpc_msg_t *msg)
{
    uint8_t func = RPC_FUNC(msg);
    sc_err_t err = SC_ERR_NONE;

    switch (func)
    {
        /* Handle uknown function */
        case IRQ_FUNC_UNKNOWN :
            {
                RPC_SIZE(msg) = 1;
                err = SC_ERR_NOTFOUND;
                RPC_R8(msg) = (uint8_t) err;
            }
            break;
        /* Dispatch enable() */
        case IRQ_FUNC_ENABLE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 4U));
                sc_irq_group_t group = ((sc_irq_group_t) RPC_U8(msg, 6U));
                uint32_t mask = ((uint32_t) RPC_U32(msg, 0U));
                sc_bool_t enable = U2B(RPC_U8(msg, 7U));

                /* Call function */
                err = irq_enable(caller_pt, resource, group, mask, enable);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch status() */
        case IRQ_FUNC_STATUS :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_irq_group_t group = ((sc_irq_group_t) RPC_U8(msg, 2U));
                uint32_t status = ((uint32_t) 0U);

                /* Call function */
                err = irq_status(caller_pt, resource, group, &status);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(status);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Handle default */
        default :
            {
                RPC_SIZE(msg) = 1;
                err = SC_ERR_NOTFOUND;
                RPC_R8(msg) = (uint8_t) err;
            }
            break;
    }

    /* Fill in header */
    RPC_VER(msg) = SC_RPC_VERSION;
    RPC_SVC(msg) = (uint8_t) SC_RPC_SVC_RETURN;

    /* Handle error debug */
    if (err != SC_ERR_NONE)
    {
        if (rpc_debug)
        {
            always_print("ipc_err: api=irq, func=%d, err=%d\n", func, err);
        }
        else
        {
            rpc_print(0, "ipc_err: api=irq, func=%d, err=%d\n", func, err);
        }
    }
}

/** @} */

