/*
** ###################################################################
**
**     Copyright (c) 2016 Freescale Semiconductor, Inc.
**     Copyright 2017-2020 NXP
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of the copyright holder nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
** ###################################################################
*/

/*==========================================================================*/
/*!
 * @file
 *
 * File containing server-side RPC functions for the MISC service.
 *
 * @addtogroup MISC_SVC
 * @{
 */
/*==========================================================================*/

/* DO NOT EDIT - This file auto generated by bin/perl/rpc_srv_c.pl */

/* Includes */

#include "main/scfw.h"
#include "main/types.h"
#include "main/main.h"
#include "main/rpc.h"
#include "svc/misc/svc.h"
#include "svc/misc/rpc.h"

/* Local Defines */

/* Local Types */

/*--------------------------------------------------------------------------*/
/* Dispatch incoming RPC function call                                      */
/*--------------------------------------------------------------------------*/
void misc_dispatch(sc_rm_pt_t caller_pt, sc_rsrc_t mu, sc_rpc_msg_t *msg)
{
    uint8_t func = RPC_FUNC(msg);
    sc_err_t err = SC_ERR_NONE;

    switch (func)
    {
        /* Handle uknown function */
        case MISC_FUNC_UNKNOWN :
            {
                RPC_SIZE(msg) = 1;
                err = SC_ERR_NOTFOUND;
                RPC_R8(msg) = (uint8_t) err;
            }
            break;
        /* Dispatch set_control() */
        case MISC_FUNC_SET_CONTROL :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 8U));
                sc_ctrl_t ctrl = ((sc_ctrl_t) RPC_U32(msg, 0U));
                uint32_t val = ((uint32_t) RPC_U32(msg, 4U));

                /* Call function */
                err = misc_set_control(caller_pt, resource, ctrl, val);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch get_control() */
        case MISC_FUNC_GET_CONTROL :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 4U));
                sc_ctrl_t ctrl = ((sc_ctrl_t) RPC_U32(msg, 0U));
                uint32_t val = ((uint32_t) 0U);

                /* Call function */
                err = misc_get_control(caller_pt, resource, ctrl, &val);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(val);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch set_max_dma_group() */
        case MISC_FUNC_SET_MAX_DMA_GROUP :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));
                sc_misc_dma_group_t max = ((sc_misc_dma_group_t) RPC_U8(msg, 1U));

                /* Call function */
                err = misc_set_max_dma_group(caller_pt, pt, max);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_dma_group() */
        case MISC_FUNC_SET_DMA_GROUP :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_misc_dma_group_t group = ((sc_misc_dma_group_t) RPC_U8(msg, 2U));

                /* Call function */
                err = misc_set_dma_group(caller_pt, resource, group);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch debug_out() */
        case MISC_FUNC_DEBUG_OUT :
            {
                /* Declare return and parameters */
                uint8_t ch = ((uint8_t) RPC_U8(msg, 0U));

                /* Call function */
                misc_debug_out(caller_pt, ch);

                /* Copy in return parameters */
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch waveform_capture() */
        case MISC_FUNC_WAVEFORM_CAPTURE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_bool_t enable = U2B(RPC_U8(msg, 0U));

                /* Call function */
                err = misc_waveform_capture(caller_pt, enable);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch build_info() */
        case MISC_FUNC_BUILD_INFO :
            {
                /* Declare return and parameters */
                uint32_t build = ((uint32_t) 0U);
                uint32_t commit = ((uint32_t) 0U);

                /* Call function */
                misc_build_info(caller_pt, &build, &commit);

                /* Copy in return parameters */
                RPC_U32(msg, 0U) = U32(build);
                RPC_U32(msg, 4U) = U32(commit);
                RPC_SIZE(msg) = 3U;
                break;
            }
        /* Dispatch api_ver() */
        case MISC_FUNC_API_VER :
            {
                /* Declare return and parameters */
                uint16_t cl_maj = ((uint16_t) 0U);
                uint16_t cl_min = ((uint16_t) 0U);
                uint16_t sv_maj = ((uint16_t) 0U);
                uint16_t sv_min = ((uint16_t) 0U);

                /* Call function */
                misc_api_ver(caller_pt, &cl_maj, &cl_min, &sv_maj, &sv_min);

                /* Copy in return parameters */
                RPC_U16(msg, 0U) = U16(cl_maj);
                RPC_U16(msg, 2U) = U16(cl_min);
                RPC_U16(msg, 4U) = U16(sv_maj);
                RPC_U16(msg, 6U) = U16(sv_min);
                RPC_SIZE(msg) = 3U;
                break;
            }
        /* Dispatch unique_id() */
        case MISC_FUNC_UNIQUE_ID :
            {
                /* Declare return and parameters */
                uint32_t id_l = ((uint32_t) 0U);
                uint32_t id_h = ((uint32_t) 0U);

                /* Call function */
                misc_unique_id(caller_pt, &id_l, &id_h);

                /* Copy in return parameters */
                RPC_U32(msg, 0U) = U32(id_l);
                RPC_U32(msg, 4U) = U32(id_h);
                RPC_SIZE(msg) = 3U;
                break;
            }
        /* Dispatch set_ari() */
        case MISC_FUNC_SET_ARI :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_rsrc_t resource_mst = ((sc_rsrc_t) RPC_U16(msg, 2U));
                uint16_t ari = ((uint16_t) RPC_U16(msg, 4U));
                sc_bool_t enable = U2B(RPC_U8(msg, 6U));

                /* Call function */
                err = misc_set_ari(caller_pt, resource, resource_mst, ari,
                    enable);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch boot_status() */
        case MISC_FUNC_BOOT_STATUS :
            {
                /* Declare return and parameters */
                sc_misc_boot_status_t status = ((sc_misc_boot_status_t) RPC_U8(msg, 0U));

                /* Call function */
                misc_boot_status(caller_pt, status);

                /* Copy in return parameters */
                RPC_SIZE(msg) = 0U;
                break;
            }
        /* Dispatch boot_done() */
        case MISC_FUNC_BOOT_DONE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t cpu = ((sc_rsrc_t) RPC_U16(msg, 0U));

                /* Call function */
                err = misc_boot_done(caller_pt, cpu);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch otp_fuse_read() */
        case MISC_FUNC_OTP_FUSE_READ :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint32_t word = ((uint32_t) RPC_U32(msg, 0U));
                uint32_t val = ((uint32_t) 0U);

                /* Call function */
                err = misc_otp_fuse_read(caller_pt, word, &val);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(val);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch otp_fuse_write() */
        case MISC_FUNC_OTP_FUSE_WRITE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint32_t word = ((uint32_t) RPC_U32(msg, 0U));
                uint32_t val = ((uint32_t) RPC_U32(msg, 4U));

                /* Call function */
                err = misc_otp_fuse_write(caller_pt, word, val);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_temp() */
        case MISC_FUNC_SET_TEMP :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_misc_temp_t temp = ((sc_misc_temp_t) RPC_U8(msg, 4U));
                int16_t celsius = ((int16_t) RPC_I16(msg, 2U));
                int8_t tenths = ((int8_t) RPC_I8(msg, 5U));

                /* Call function */
                err = misc_set_temp(caller_pt, resource, temp, celsius, tenths);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch get_temp() */
        case MISC_FUNC_GET_TEMP :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_misc_temp_t temp = ((sc_misc_temp_t) RPC_U8(msg, 2U));
                int16_t celsius = ((int16_t) 0U);
                int8_t tenths = ((int8_t) 0U);

                /* Call function */
                err = misc_get_temp(caller_pt, resource, temp, &celsius,
                    &tenths);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_I16(msg, 0U) = I16(celsius);
                RPC_I8(msg, 2U) = I8(tenths);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch get_boot_dev() */
        case MISC_FUNC_GET_BOOT_DEV :
            {
                /* Declare return and parameters */
                sc_rsrc_t dev = ((sc_rsrc_t) 0U);

                /* Call function */
                misc_get_boot_dev(caller_pt, &dev);

                /* Copy in return parameters */
                RPC_U16(msg, 0U) = U16(dev);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch get_boot_type() */
        case MISC_FUNC_GET_BOOT_TYPE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_misc_bt_t type = ((sc_misc_bt_t) 0U);

                /* Call function */
                err = misc_get_boot_type(caller_pt, &type);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U8(msg, 0U) = U8(type);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch get_boot_container() */
        case MISC_FUNC_GET_BOOT_CONTAINER :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint8_t idx = ((uint8_t) 0U);

                /* Call function */
                err = misc_get_boot_container(caller_pt, &idx);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U8(msg, 0U) = U8(idx);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch get_button_status() */
        case MISC_FUNC_GET_BUTTON_STATUS :
            {
                /* Declare return and parameters */
                sc_bool_t status = SC_FALSE;

                /* Call function */
                misc_get_button_status(caller_pt, &status);

                /* Copy in return parameters */
                RPC_U8(msg, 0U) = B2U8(status);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch rompatch_checksum() */
        case MISC_FUNC_ROMPATCH_CHECKSUM :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint32_t checksum = ((uint32_t) 0U);

                /* Call function */
                err = misc_rompatch_checksum(caller_pt, &checksum);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(checksum);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch board_ioctl() */
        case MISC_FUNC_BOARD_IOCTL :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint32_t parm1 = ((uint32_t) RPC_U32(msg, 0U));
                uint32_t parm2 = ((uint32_t) RPC_U32(msg, 4U));
                uint32_t parm3 = ((uint32_t) RPC_U32(msg, 8U));

                /* Call function */
                err = misc_board_ioctl(mu, &parm1, &parm2, &parm3);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(parm1);
                RPC_U32(msg, 4U) = U32(parm2);
                RPC_U32(msg, 8U) = U32(parm3);
                RPC_SIZE(msg) = 4U;
                break;
            }
        /* Handle default */
        default :
            {
                RPC_SIZE(msg) = 1;
                err = SC_ERR_NOTFOUND;
                RPC_R8(msg) = (uint8_t) err;
            }
            break;
    }

    /* Fill in header */
    RPC_VER(msg) = SC_RPC_VERSION;
    RPC_SVC(msg) = (uint8_t) SC_RPC_SVC_RETURN;

    /* Handle error debug */
    if (err != SC_ERR_NONE)
    {
        if (rpc_debug)
        {
            always_print("ipc_err: api=misc, func=%d, err=%d\n", func, err);
        }
        else
        {
            rpc_print(0, "ipc_err: api=misc, func=%d, err=%d\n", func, err);
        }
    }
}

/** @} */

