/*
** ###################################################################
**
**     Copyright (c) 2016 Freescale Semiconductor, Inc.
**     Copyright 2017-2020 NXP
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of the copyright holder nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
** ###################################################################
*/

/*==========================================================================*/
/*!
 * @file
 *
 * File containing server-side RPC functions for the PM service.
 *
 * @addtogroup PM_SVC
 * @{
 */
/*==========================================================================*/

/* DO NOT EDIT - This file auto generated by bin/perl/rpc_srv_c.pl */

/* Includes */

#include "main/scfw.h"
#include "main/types.h"
#include "main/main.h"
#include "main/rpc.h"
#include "svc/pm/svc.h"
#include "svc/pm/rpc.h"

/* Local Defines */

/* Local Types */

/*--------------------------------------------------------------------------*/
/* Dispatch incoming RPC function call                                      */
/*--------------------------------------------------------------------------*/
void pm_dispatch(sc_rm_pt_t caller_pt, sc_rsrc_t mu, sc_rpc_msg_t *msg)
{
    uint8_t func = RPC_FUNC(msg);
    sc_err_t err = SC_ERR_NONE;

    switch (func)
    {
        /* Handle uknown function */
        case PM_FUNC_UNKNOWN :
            {
                RPC_SIZE(msg) = 1;
                err = SC_ERR_NOTFOUND;
                RPC_R8(msg) = (uint8_t) err;
            }
            break;
        /* Dispatch set_sys_power_mode() */
        case PM_FUNC_SET_SYS_POWER_MODE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_pm_power_mode_t mode = ((sc_pm_power_mode_t) RPC_U8(msg, 0U));

                /* Call function */
                err = pm_set_sys_power_mode(caller_pt, mode);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_partition_power_mode() */
        case PM_FUNC_SET_PARTITION_POWER_MODE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));
                sc_pm_power_mode_t mode = ((sc_pm_power_mode_t) RPC_U8(msg, 1U));

                /* Call function */
                err = pm_set_partition_power_mode(caller_pt, pt, mode);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch partition_power_off() */
        case PM_FUNC_PARTITION_POWER_OFF :
            {
                /* Declare return and parameters */

                /* Call function */
                pm_partition_power_off(caller_pt);

                /* Copy in return parameters */
                RPC_SIZE(msg) = 0U;
                break;
            }
        /* Dispatch get_sys_power_mode() */
        case PM_FUNC_GET_SYS_POWER_MODE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));
                sc_pm_power_mode_t mode = ((sc_pm_power_mode_t) 0U);

                /* Call function */
                err = pm_get_sys_power_mode(caller_pt, pt, &mode);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U8(msg, 0U) = U8(mode);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch partition_wake() */
        case PM_FUNC_PARTITION_WAKE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));

                /* Call function */
                err = pm_partition_wake(caller_pt, pt);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_resource_power_mode() */
        case PM_FUNC_SET_RESOURCE_POWER_MODE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_power_mode_t mode = ((sc_pm_power_mode_t) RPC_U8(msg, 2U));

                /* Call function */
                err = pm_set_resource_power_mode(mu, resource, mode);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_resource_power_mode_all() */
        case PM_FUNC_SET_RESOURCE_POWER_MODE_ALL :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 2U));
                sc_pm_power_mode_t mode = ((sc_pm_power_mode_t) RPC_U8(msg, 3U));
                sc_rsrc_t exclude = ((sc_rsrc_t) RPC_U16(msg, 0U));

                /* Call function */
                err = pm_set_resource_power_mode_all(caller_pt, pt, mode,
                    exclude);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch get_resource_power_mode() */
        case PM_FUNC_GET_RESOURCE_POWER_MODE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_power_mode_t mode = ((sc_pm_power_mode_t) 0U);

                /* Call function */
                err = pm_get_resource_power_mode(caller_pt, resource, &mode);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U8(msg, 0U) = U8(mode);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch req_low_power_mode() */
        case PM_FUNC_REQ_LOW_POWER_MODE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_power_mode_t mode = ((sc_pm_power_mode_t) RPC_U8(msg, 2U));

                /* Call function */
                err = pm_req_low_power_mode(caller_pt, resource, mode);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch req_cpu_low_power_mode() */
        case PM_FUNC_REQ_CPU_LOW_POWER_MODE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_power_mode_t mode = ((sc_pm_power_mode_t) RPC_U8(msg, 2U));
                sc_pm_wake_src_t wake_src = ((sc_pm_wake_src_t) RPC_U8(msg, 3U));

                /* Call function */
                err = pm_req_cpu_low_power_mode(caller_pt, resource, mode,
                    wake_src);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_cpu_resume_addr() */
        case PM_FUNC_SET_CPU_RESUME_ADDR :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 8U));
                sc_faddr_t address = ((sc_faddr_t) RPC_U64(msg, 0U));

                /* Call function */
                err = pm_set_cpu_resume_addr(caller_pt, resource, address);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_cpu_resume() */
        case PM_FUNC_SET_CPU_RESUME :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 8U));
                sc_bool_t isPrimary = U2B(RPC_U8(msg, 10U));
                sc_faddr_t address = ((sc_faddr_t) RPC_U64(msg, 0U));

                /* Call function */
                err = pm_set_cpu_resume(caller_pt, resource, isPrimary,
                    address);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch req_sys_if_power_mode() */
        case PM_FUNC_REQ_SYS_IF_POWER_MODE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_sys_if_t sys_if = ((sc_pm_sys_if_t) RPC_U8(msg, 2U));
                sc_pm_power_mode_t hpm = ((sc_pm_power_mode_t) RPC_U8(msg, 3U));
                sc_pm_power_mode_t lpm = ((sc_pm_power_mode_t) RPC_U8(msg, 4U));

                /* Call function */
                err = pm_req_sys_if_power_mode(caller_pt, resource, sys_if, hpm,
                    lpm);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_clock_rate() */
        case PM_FUNC_SET_CLOCK_RATE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 4U));
                sc_pm_clk_t clk = ((sc_pm_clk_t) RPC_U8(msg, 6U));
                sc_pm_clock_rate_t rate = ((sc_pm_clock_rate_t) RPC_U32(msg, 0U));

                /* Call function */
                err = pm_set_clock_rate(caller_pt, resource, clk, &rate);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(rate);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch get_clock_rate() */
        case PM_FUNC_GET_CLOCK_RATE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_clk_t clk = ((sc_pm_clk_t) RPC_U8(msg, 2U));
                sc_pm_clock_rate_t rate = ((sc_pm_clock_rate_t) 0U);

                /* Call function */
                err = pm_get_clock_rate(caller_pt, resource, clk, &rate);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(rate);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch clock_enable() */
        case PM_FUNC_CLOCK_ENABLE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_clk_t clk = ((sc_pm_clk_t) RPC_U8(msg, 2U));
                sc_bool_t enable = U2B(RPC_U8(msg, 3U));
                sc_bool_t autog = U2B(RPC_U8(msg, 4U));

                /* Call function */
                err = pm_clock_enable(caller_pt, resource, clk, enable, autog);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_clock_parent() */
        case PM_FUNC_SET_CLOCK_PARENT :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_clk_t clk = ((sc_pm_clk_t) RPC_U8(msg, 2U));
                sc_pm_clk_parent_t parent = ((sc_pm_clk_parent_t) RPC_U8(msg, 3U));

                /* Call function */
                err = pm_set_clock_parent(caller_pt, resource, clk, parent);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch get_clock_parent() */
        case PM_FUNC_GET_CLOCK_PARENT :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));
                sc_pm_clk_t clk = ((sc_pm_clk_t) RPC_U8(msg, 2U));
                sc_pm_clk_parent_t parent = ((sc_pm_clk_parent_t) 0U);

                /* Call function */
                err = pm_get_clock_parent(caller_pt, resource, clk, &parent);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U8(msg, 0U) = U8(parent);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch reset() */
        case PM_FUNC_RESET :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_pm_reset_type_t type = ((sc_pm_reset_type_t) RPC_U8(msg, 0U));

                /* Call function */
                err = pm_reset(caller_pt, type);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch reset_reason() */
        case PM_FUNC_RESET_REASON :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_pm_reset_reason_t reason = ((sc_pm_reset_reason_t) 0U);

                /* Call function */
                err = pm_reset_reason(caller_pt, &reason);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U8(msg, 0U) = U8(reason);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch get_reset_part() */
        case PM_FUNC_GET_RESET_PART :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) 0U);

                /* Call function */
                err = pm_get_reset_part(caller_pt, &pt);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U8(msg, 0U) = U8(pt);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch boot() */
        case PM_FUNC_BOOT :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 14U));
                sc_rsrc_t resource_cpu = ((sc_rsrc_t) RPC_U16(msg, 8U));
                sc_faddr_t boot_addr = ((sc_faddr_t) RPC_U64(msg, 0U));
                sc_rsrc_t resource_mu = ((sc_rsrc_t) RPC_U16(msg, 10U));
                sc_rsrc_t resource_dev = ((sc_rsrc_t) RPC_U16(msg, 12U));

                /* Call function */
                err = pm_boot(caller_pt, pt, resource_cpu, boot_addr,
                    resource_mu, resource_dev);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_boot_parm() */
        case PM_FUNC_SET_BOOT_PARM :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource_cpu = ((sc_rsrc_t) RPC_U16(msg, 8U));
                sc_faddr_t boot_addr = ((sc_faddr_t) RPC_U64(msg, 0U));
                sc_rsrc_t resource_mu = ((sc_rsrc_t) RPC_U16(msg, 10U));
                sc_rsrc_t resource_dev = ((sc_rsrc_t) RPC_U16(msg, 12U));

                /* Call function */
                err = pm_set_boot_parm(caller_pt, resource_cpu, boot_addr,
                    resource_mu, resource_dev);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch reboot() */
        case PM_FUNC_REBOOT :
            {
                /* Declare return and parameters */
                sc_pm_reset_type_t type = ((sc_pm_reset_type_t) RPC_U8(msg, 0U));

                /* Call function */
                pm_reboot(caller_pt, type);

                /* Copy in return parameters */
                RPC_SIZE(msg) = 0U;
                break;
            }
        /* Dispatch reboot_partition() */
        case PM_FUNC_REBOOT_PARTITION :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));
                sc_pm_reset_type_t type = ((sc_pm_reset_type_t) RPC_U8(msg, 1U));

                /* Call function */
                err = pm_reboot_partition(caller_pt, pt, type);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch reboot_continue() */
        case PM_FUNC_REBOOT_CONTINUE :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));

                /* Call function */
                err = pm_reboot_continue(caller_pt, pt);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch cpu_start() */
        case PM_FUNC_CPU_START :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 8U));
                sc_bool_t enable = U2B(RPC_U8(msg, 10U));
                sc_faddr_t address = ((sc_faddr_t) RPC_U64(msg, 0U));

                /* Call function */
                err = pm_cpu_start(caller_pt, resource, enable, address);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch cpu_reset() */
        case PM_FUNC_CPU_RESET :
            {
                /* Declare return and parameters */
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 8U));
                sc_faddr_t address = ((sc_faddr_t) RPC_U64(msg, 0U));

                /* Call function */
                pm_cpu_reset(caller_pt, resource, address);

                /* Copy in return parameters */
                RPC_SIZE(msg) = 0U;
                break;
            }
        /* Dispatch resource_reset() */
        case PM_FUNC_RESOURCE_RESET :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rsrc_t resource = ((sc_rsrc_t) RPC_U16(msg, 0U));

                /* Call function */
                err = pm_resource_reset(mu, resource);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch is_partition_started() */
        case PM_FUNC_IS_PARTITION_STARTED :
            {
                /* Declare return and parameters */
                sc_bool_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));

                /* Call function */
                result = pm_is_partition_started(caller_pt, pt);

                /* Copy in return parameters */
                RPC_R8(msg) = B2U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Handle default */
        default :
            {
                RPC_SIZE(msg) = 1;
                err = SC_ERR_NOTFOUND;
                RPC_R8(msg) = (uint8_t) err;
            }
            break;
    }

    /* Fill in header */
    RPC_VER(msg) = SC_RPC_VERSION;
    RPC_SVC(msg) = (uint8_t) SC_RPC_SVC_RETURN;

    /* Handle error debug */
    if (err != SC_ERR_NONE)
    {
        if (rpc_debug)
        {
            always_print("ipc_err: api=pm, func=%d, err=%d\n", func, err);
        }
        else
        {
            rpc_print(0, "ipc_err: api=pm, func=%d, err=%d\n", func, err);
        }
    }
}

/** @} */

