/*
** ###################################################################
**
**     Copyright (c) 2016 Freescale Semiconductor, Inc.
**     Copyright 2017-2020 NXP
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of the copyright holder nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
** ###################################################################
*/

/*==========================================================================*/
/*!
 * @file
 *
 * File containing server-side RPC functions for the TIMER service.
 *
 * @addtogroup TIMER_SVC
 * @{
 */
/*==========================================================================*/

/* DO NOT EDIT - This file auto generated by bin/perl/rpc_srv_c.pl */

/* Includes */

#include "main/scfw.h"
#include "main/types.h"
#include "main/main.h"
#include "main/rpc.h"
#include "svc/timer/svc.h"
#include "svc/timer/rpc.h"

/* Local Defines */

/* Local Types */

/*--------------------------------------------------------------------------*/
/* Dispatch incoming RPC function call                                      */
/*--------------------------------------------------------------------------*/
void timer_dispatch(sc_rm_pt_t caller_pt, sc_rsrc_t mu, sc_rpc_msg_t *msg)
{
    uint8_t func = RPC_FUNC(msg);
    sc_err_t err = SC_ERR_NONE;

    switch (func)
    {
        /* Handle uknown function */
        case TIMER_FUNC_UNKNOWN :
            {
                RPC_SIZE(msg) = 1;
                err = SC_ERR_NOTFOUND;
                RPC_R8(msg) = (uint8_t) err;
            }
            break;
        /* Dispatch set_wdog_timeout() */
        case TIMER_FUNC_SET_WDOG_TIMEOUT :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_timer_wdog_time_t timeout = ((sc_timer_wdog_time_t) RPC_U32(msg, 0U));

                /* Call function */
                err = timer_set_wdog_timeout(caller_pt, timeout);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_wdog_pre_timeout() */
        case TIMER_FUNC_SET_WDOG_PRE_TIMEOUT :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_timer_wdog_time_t pre_timeout = ((sc_timer_wdog_time_t) RPC_U32(msg, 0U));

                /* Call function */
                err = timer_set_wdog_pre_timeout(caller_pt, pre_timeout);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_wdog_window() */
        case TIMER_FUNC_SET_WDOG_WINDOW :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_timer_wdog_time_t window = ((sc_timer_wdog_time_t) RPC_U32(msg, 0U));

                /* Call function */
                err = timer_set_wdog_window(caller_pt, window);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch start_wdog() */
        case TIMER_FUNC_START_WDOG :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_bool_t lock = U2B(RPC_U8(msg, 0U));

                /* Call function */
                err = timer_start_wdog(caller_pt, lock);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch stop_wdog() */
        case TIMER_FUNC_STOP_WDOG :
            {
                /* Declare return and parameters */
                sc_err_t result;

                /* Call function */
                err = timer_stop_wdog(caller_pt);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch ping_wdog() */
        case TIMER_FUNC_PING_WDOG :
            {
                /* Declare return and parameters */
                sc_err_t result;

                /* Call function */
                err = timer_ping_wdog(caller_pt);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch get_wdog_status() */
        case TIMER_FUNC_GET_WDOG_STATUS :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_timer_wdog_time_t timeout = ((sc_timer_wdog_time_t) 0U);
                sc_timer_wdog_time_t max_timeout = ((sc_timer_wdog_time_t) 0U);
                sc_timer_wdog_time_t remaining_time = ((sc_timer_wdog_time_t) 0U);

                /* Call function */
                err = timer_get_wdog_status(caller_pt, &timeout, &max_timeout,
                    &remaining_time);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(timeout);
                RPC_U32(msg, 4U) = U32(max_timeout);
                RPC_U32(msg, 8U) = U32(remaining_time);
                RPC_SIZE(msg) = 4U;
                break;
            }
        /* Dispatch pt_get_wdog_status() */
        case TIMER_FUNC_PT_GET_WDOG_STATUS :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));
                sc_bool_t enb = SC_FALSE;
                sc_timer_wdog_time_t timeout = ((sc_timer_wdog_time_t) 0U);
                sc_timer_wdog_time_t remaining_time = ((sc_timer_wdog_time_t) 0U);

                /* Call function */
                err = timer_pt_get_wdog_status(caller_pt, pt, &enb, &timeout,
                    &remaining_time);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U8(msg, 8U) = B2U8(enb);
                RPC_U32(msg, 0U) = U32(timeout);
                RPC_U32(msg, 4U) = U32(remaining_time);
                RPC_SIZE(msg) = 4U;
                break;
            }
        /* Dispatch set_wdog_action() */
        case TIMER_FUNC_SET_WDOG_ACTION :
            {
                /* Declare return and parameters */
                sc_err_t result;
                sc_rm_pt_t pt = ((sc_rm_pt_t) RPC_U8(msg, 0U));
                sc_timer_wdog_action_t action = ((sc_timer_wdog_action_t) RPC_U8(msg, 1U));

                /* Call function */
                err = timer_set_wdog_action(caller_pt, pt, action);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_rtc_time() */
        case TIMER_FUNC_SET_RTC_TIME :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint16_t year = ((uint16_t) RPC_U16(msg, 0U));
                uint8_t mon = ((uint8_t) RPC_U8(msg, 2U));
                uint8_t day = ((uint8_t) RPC_U8(msg, 3U));
                uint8_t hour = ((uint8_t) RPC_U8(msg, 4U));
                uint8_t min = ((uint8_t) RPC_U8(msg, 5U));
                uint8_t sec = ((uint8_t) RPC_U8(msg, 6U));

                /* Call function */
                err = timer_set_rtc_time(caller_pt, year, mon, day, hour, min,
                    sec);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch get_rtc_time() */
        case TIMER_FUNC_GET_RTC_TIME :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint16_t year = ((uint16_t) 0U);
                uint8_t mon = ((uint8_t) 0U);
                uint8_t day = ((uint8_t) 0U);
                uint8_t hour = ((uint8_t) 0U);
                uint8_t min = ((uint8_t) 0U);
                uint8_t sec = ((uint8_t) 0U);

                /* Call function */
                err = timer_get_rtc_time(caller_pt, &year, &mon, &day, &hour,
                    &min, &sec);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U16(msg, 0U) = U16(year);
                RPC_U8(msg, 2U) = U8(mon);
                RPC_U8(msg, 3U) = U8(day);
                RPC_U8(msg, 4U) = U8(hour);
                RPC_U8(msg, 5U) = U8(min);
                RPC_U8(msg, 6U) = U8(sec);
                RPC_SIZE(msg) = 3U;
                break;
            }
        /* Dispatch get_rtc_sec1970() */
        case TIMER_FUNC_GET_RTC_SEC1970 :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint32_t sec = ((uint32_t) 0U);

                /* Call function */
                err = timer_get_rtc_sec1970(caller_pt, &sec);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_U32(msg, 0U) = U32(sec);
                RPC_SIZE(msg) = 2U;
                break;
            }
        /* Dispatch set_rtc_alarm() */
        case TIMER_FUNC_SET_RTC_ALARM :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint16_t year = ((uint16_t) RPC_U16(msg, 0U));
                uint8_t mon = ((uint8_t) RPC_U8(msg, 2U));
                uint8_t day = ((uint8_t) RPC_U8(msg, 3U));
                uint8_t hour = ((uint8_t) RPC_U8(msg, 4U));
                uint8_t min = ((uint8_t) RPC_U8(msg, 5U));
                uint8_t sec = ((uint8_t) RPC_U8(msg, 6U));

                /* Call function */
                err = timer_set_rtc_alarm(caller_pt, year, mon, day, hour, min,
                    sec);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_rtc_periodic_alarm() */
        case TIMER_FUNC_SET_RTC_PERIODIC_ALARM :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint32_t sec = ((uint32_t) RPC_U32(msg, 0U));

                /* Call function */
                err = timer_set_rtc_periodic_alarm(caller_pt, sec);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch cancel_rtc_alarm() */
        case TIMER_FUNC_CANCEL_RTC_ALARM :
            {
                /* Declare return and parameters */
                sc_err_t result;

                /* Call function */
                err = timer_cancel_rtc_alarm(caller_pt);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_rtc_calb() */
        case TIMER_FUNC_SET_RTC_CALB :
            {
                /* Declare return and parameters */
                sc_err_t result;
                int8_t count = ((int8_t) RPC_I8(msg, 0U));

                /* Call function */
                err = timer_set_rtc_calb(caller_pt, count);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_sysctr_alarm() */
        case TIMER_FUNC_SET_SYSCTR_ALARM :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint64_t ticks = ((uint64_t) RPC_U64(msg, 0U));

                /* Call function */
                err = timer_set_sysctr_alarm(caller_pt, ticks);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch set_sysctr_periodic_alarm() */
        case TIMER_FUNC_SET_SYSCTR_PERIODIC_ALARM :
            {
                /* Declare return and parameters */
                sc_err_t result;
                uint64_t ticks = ((uint64_t) RPC_U64(msg, 0U));

                /* Call function */
                err = timer_set_sysctr_periodic_alarm(caller_pt, ticks);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Dispatch cancel_sysctr_alarm() */
        case TIMER_FUNC_CANCEL_SYSCTR_ALARM :
            {
                /* Declare return and parameters */
                sc_err_t result;

                /* Call function */
                err = timer_cancel_sysctr_alarm(caller_pt);
                result = err;

                /* Copy in return parameters */
                RPC_R8(msg) = U8(result);
                RPC_SIZE(msg) = 1U;
                break;
            }
        /* Handle default */
        default :
            {
                RPC_SIZE(msg) = 1;
                err = SC_ERR_NOTFOUND;
                RPC_R8(msg) = (uint8_t) err;
            }
            break;
    }

    /* Fill in header */
    RPC_VER(msg) = SC_RPC_VERSION;
    RPC_SVC(msg) = (uint8_t) SC_RPC_SVC_RETURN;

    /* Handle error debug */
    if (err != SC_ERR_NONE)
    {
        if (rpc_debug)
        {
            always_print("ipc_err: api=timer, func=%d, err=%d\n", func, err);
        }
        else
        {
            rpc_print(0, "ipc_err: api=timer, func=%d, err=%d\n", func, err);
        }
    }
}

/** @} */

